/*
TECNISA - TECNOLOGIA EM INFORMTICA

NOME: APURAC_RELGESMERENDA

DESCRIO:
PROCEDIMENTO PARA APURAO DE FATURAMENTO DE CLIENTES EM FILIAIS
QUE UTILIZAM O TIPO DE CONTRATO GESTO MERENDA.

@C:\WEB_505\SQL\End_Conv\SQLServer\6214_FAISTPS.SQL
*/

IF EXISTS (SELECT *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'APURAC_GESMERENDA' AND
                 TYPE = 'P' 			         AND
                 U.UID = O.UID             	AND
                 U.NAME = USER)
DROP PROCEDURE APURAC_RELGESMERENDA
GO
CREATE PROCEDURE APURAC_RELGESMERENDA
(
   @P_CDFILCENTPME VARCHAR(04),
   @P_CDFILIAL     VARCHAR(04),
   @P_CDCLIENTE    VARCHAR(21),
   @P_DATAINI      DATETIME,
   @P_DATAFIM      DATETIME,
   @P_NRAPURACFAT  VARCHAR(10),
   @P_IDGERANOTA   VARCHAR(01) = 'S',
   @P_DTSAIDAPUR   DATETIME = NULL
)
AS
   /* VARIVEIS PARA CONTROLE DE PARAMETROS */
   DECLARE @STIDUTEFEPLA VARCHAR(01);

   /*VARIAVEIS DO LOOP C_GMERENDA*/
   DECLARE @V_CDFILCENTPME VARCHAR(04);
   DECLARE @V_CDFILIAL     VARCHAR(04);
   DECLARE @V_CDCLIENTE    VARCHAR(21);
   DECLARE @V_CDTIPOCARD   VARCHAR(10)
   DECLARE @V_CDSERVFILI   VARCHAR(05);
   DECLARE @V_DTFATURAM    DATETIME;
   DECLARE @V_CDPRODUTO    VARCHAR(10);
   DECLARE @V_VRSERVICO    DOUBLE PRECISION;
   DECLARE @V_QTEFETSERV   DOUBLE PRECISION;
   DECLARE @V_NMSERVICO  VARCHAR(400);

   /*VARIAVEIS DO LOOP CURS_NF*/
   DECLARE @V_CDFILIALDEL   VARCHAR(04);
   DECLARE @V_NRLANCTONFDEL VARCHAR(10);

   /*VARIAVEIS DO LOOP CURS_APURAC*/
   DECLARE @V_CDFILCENTAPGM  VARCHAR(04);
   DECLARE @V_CDFILIALAPGM   VARCHAR(04);
   DECLARE @V_CDCLIENTEAPGM  VARCHAR(21);
   DECLARE @V_CDTIPOCARDAPGM VARCHAR(10);
   DECLARE @V_CDSERVFILIAPGM VARCHAR(05);
   DECLARE @V_CDPRODUTOAPGM  VARCHAR(10);
   DECLARE @V_NREFETIVOSAPGM DOUBLE PRECISION;
   DECLARE @V_VRPRECUNITAPGM DOUBLE PRECISION;

   /* VARIVEIS PARA CONTROLE DE APURAO */
   DECLARE @V_EXISTE     DOUBLE PRECISION;

   DECLARE @V_CDSERIE      VARCHAR(05);
   DECLARE @V_TTITENSNF    DOUBLE PRECISION;
   DECLARE @V_CONTITEM     DOUBLE PRECISION;
   DECLARE @V_NRLANCTONF   VARCHAR(20);
   DECLARE @V_NRSEQITPROD  DOUBLE PRECISION;
   DECLARE @V_CDEMPRESA    VARCHAR(02);
   DECLARE @V_CDINSCMUNI   VARCHAR(16);
   DECLARE @V_CDINSCESTA   VARCHAR(16);
   DECLARE @V_IDTPIJURCLIE VARCHAR(01)
   DECLARE @V_NRINSJURCLIE VARCHAR(20);
   DECLARE @V_IDNOVANOTA   VARCHAR(01);
   DECLARE @V_PRXLANCESTQ  VARCHAR(10);
   DECLARE @V_IDUTPROPEMIS VARCHAR(01);
   DECLARE @V_CONTADOR     VARCHAR(17);

   DECLARE @V_CDARVPROD    VARCHAR(10);
   DECLARE @V_NMPRODUTO    VARCHAR(50);

BEGIN

   SELECT @STIDUTEFEPLA = MAX(SUBSTRING(DSPARAMFATFI,15,1)) /*UTILIZA EFETIVOS DO PLANEJAMENTO MERENDA*/
   FROM PARAMFILIAL
   WHERE CDFILIAL = @P_CDFILCENTPME;

   SELECT @V_IDUTPROPEMIS = ISNULL(MAX(IDUTPROPEMIS),'N')
   FROM PARAMGERAL;

   /* APAGA OS REGISTROS DA TRAB_APURAC_GM DE APURACOES ANTERIORES */
   DELETE FROM TRAB_APURAC_GM
   WHERE CDFILCENTAPGM  = @P_CDFILCENTPME
     AND CDFILIALAPGM = @P_CDFILIAL
     AND NRAPURACGM = @P_NRAPURACFAT
     AND CDCLIENTEAPGM = @P_CDCLIENTE;


   IF (@STIDUTEFEPLA IS NULL) OR (@STIDUTEFEPLA = ' ') BEGIN
      SET @STIDUTEFEPLA = 'N';
      -- NAO UTILIZA EFETIVOS DO PLANEJAMENTO
   END;


   /* ABRE O CURSOR */
   DECLARE C_GDIRETA CURSOR FOR
      SELECT CDFILCENTPME, CDFILIAL, CDCLIENTE, CDTIPOCARD, CDSERVFILI, DTFATURAM, 
             CDPRODUTO,
             VRSERVICO,
             QTEFETIVOS,
             NMSERVICO                
      FROM
      (
      SELECT CDFILCENTPME, CDFILIAL, CDCLIENTE, CDTIPOCARD, CDSERVFILI, DTFATURAM, 
             CDPRODUTO,
             TEKNISA.VALOR_SERVICO_MERENDA(CDFILCENTPME, CDTIPOCARD, CDFILIAL, CDSERVFILI, CDCLIENTE, DTFATURAM) AS VRSERVICO,
             QTEFETIVOS,
             NMSERVICO                
      FROM
      (
      SELECT EFECLIFATMER.CDFILCENTPME, EFECLIFATMER.CDFILIAL,
             EFECLIFATMER.CDCLIENTE, EFECLIFATMER.CDTIPOCARD, EFECLIFATMER.CDSERVFILI, EFECLIFATMER.DTEFETFATMER AS DTFATURAM,
             SERVICO.CDPRODUTO, SUM(EFECLIFATMER.QTCOMEFATMER) AS QTEFETIVOS, SERVICO.NMSERVICO
        FROM EFECLIFATMER, SERVCLIEPME, SERVICO
       WHERE EFECLIFATMER.CDFILCENTPME = SERVCLIEPME.CDFILCENTPME
         AND EFECLIFATMER.CDFILIAL = SERVCLIEPME.CDFILIAL
         AND EFECLIFATMER.CDTIPOCARD = SERVCLIEPME.CDTIPOCARD
         AND EFECLIFATMER.CDCLIENTE = SERVCLIEPME.CDCLIENTE
         AND EFECLIFATMER.CDSERVFILI = SERVCLIEPME.CDSERVFILI
         AND SERVICO.CDFILIAL = EFECLIFATMER.CDFILIAL
         AND SERVICO.CDSERVFILI = EFECLIFATMER.CDSERVFILI
         AND EFECLIFATMER.DTEFETFATMER BETWEEN @P_DATAINI AND @P_DATAFIM
         AND @STIDUTEFEPLA = 'N'
         AND EFECLIFATMER.CDFILIAL   = @P_CDFILIAL
         AND EFECLIFATMER.CDCLIENTE  = @P_CDCLIENTE
      GROUP BY EFECLIFATMER.CDFILCENTPME, EFECLIFATMER.CDFILIAL, EFECLIFATMER.CDCLIENTE,
               EFECLIFATMER.CDTIPOCARD, EFECLIFATMER.DTEFETFATMER, EFECLIFATMER.CDSERVFILI,
               SERVICO.CDPRODUTO, SERVICO.NMSERVICO
        HAVING (SUM(EFECLIFATMER.QTCOMEFATMER) <> 0)
      UNION
      SELECT EFETCLIEPME.CDFILCENTPME, EFETCLIEPME.CDFILIAL,
             EFETCLIEPME.CDCLIENTE, EFETCLIEPME.CDTIPOCARD, EFETCLIEPME.CDSERVFILI, EFETCLIEPME.DTEFETCLPME AS DTFATURAM,
             SERVICO.CDPRODUTO, SUM(EFETCLIEPME.QTCOMEFCLPME) AS QTEFETIVOS, SERVICO.NMSERVICO
        FROM EFETCLIEPME, SERVCLIEPME, SERVICO
       WHERE EFETCLIEPME.CDFILCENTPME = SERVCLIEPME.CDFILCENTPME
         AND EFETCLIEPME.CDFILIAL = SERVCLIEPME.CDFILIAL
         AND EFETCLIEPME.CDTIPOCARD = SERVCLIEPME.CDTIPOCARD
         AND EFETCLIEPME.CDCLIENTE = SERVCLIEPME.CDCLIENTE
         AND EFETCLIEPME.CDSERVFILI = SERVCLIEPME.CDSERVFILI
         AND SERVICO.CDFILIAL = EFETCLIEPME.CDFILIAL
         AND SERVICO.CDSERVFILI = EFETCLIEPME.CDSERVFILI
         AND EFETCLIEPME.DTEFETCLPME BETWEEN @P_DATAINI AND @P_DATAFIM
         AND @STIDUTEFEPLA = 'S'
         AND EFETCLIEPME.CDFILIAL   = @P_CDFILIAL
         AND EFETCLIEPME.CDCLIENTE  = @P_CDCLIENTE
      GROUP BY EFETCLIEPME.CDFILCENTPME, EFETCLIEPME.CDFILIAL, EFETCLIEPME.CDCLIENTE,
               EFETCLIEPME.CDTIPOCARD, EFETCLIEPME.DTEFETCLPME, EFETCLIEPME.CDSERVFILI,
               SERVICO.CDPRODUTO, SERVICO.NMSERVICO
       HAVING (SUM(EFETCLIEPME.QTCOMEFCLPME) <> 0)
      ) S ) S
      WHERE VRSERVICO <> 0;

   OPEN C_GDIRETA;
   FETCH NEXT FROM C_GDIRETA INTO @V_CDFILCENTPME, @V_CDFILIAL, @V_CDCLIENTE, @V_CDTIPOCARD, @V_CDSERVFILI, @V_DTFATURAM,
                                  @V_CDPRODUTO, @V_VRSERVICO, @V_QTEFETSERV, @V_NMSERVICO;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      /* GRAVA OS SERVICOS NA TRAB_APURAC_GD JA COM AS QUANTIDADES
         E VALORES CORRIGIDOS */

      SELECT @V_EXISTE = COUNT(*)
        FROM TRAB_APURAC_GM
       WHERE CDFILCENTAPGM   = @P_CDFILCENTPME
         AND CDFILIALAPGM   = @V_CDFILIAL
         AND NRAPURACGM     = @P_NRAPURACFAT
         AND CDCLIENTEAPGM  = @V_CDCLIENTE
         AND CDTIPOCARDAPGM   = @V_CDTIPOCARD
         AND CDSERVFILIAPGM = @V_CDSERVFILI
         AND ROUND(VRPRECUNITAPGM,2) = ROUND(@V_VRSERVICO,2);

      IF (@V_EXISTE = 0) BEGIN

         INSERT INTO TRAB_APURAC_GM
           (CDFILCENTAPGM, CDFILIALAPGM, NRAPURACGM, CDCLIENTEAPGM,
            CDTIPOCARDAPGM, CDSERVFILIAPGM, DTAPURACFATGM, CDPRODUTOAPGM,
            NREFETIVOSAPGM, VRPRECUNITAPGM)
         VALUES (@P_CDFILCENTPME, @P_CDFILIAL, @P_NRAPURACFAT, @V_CDCLIENTE,
                 @V_CDTIPOCARD, @V_CDSERVFILI, @P_DATAINI, @V_CDPRODUTO,
                 @V_QTEFETSERV, @V_VRSERVICO);
      END
      ELSE BEGIN
         UPDATE TRAB_APURAC_GM
            SET NREFETIVOSAPGM = NREFETIVOSAPGM + @V_QTEFETSERV
          WHERE CDFILCENTAPGM    = @P_CDFILCENTPME
            AND CDFILIALAPGM   = @V_CDFILIAL
            AND NRAPURACGM     = @P_NRAPURACFAT
            AND CDCLIENTEAPGM  = @V_CDCLIENTE
            AND CDTIPOCARDAPGM   = @V_CDTIPOCARD
            AND CDSERVFILIAPGM = @V_CDSERVFILI
            AND ROUND(VRPRECUNITAPGM,2) = ROUND(@V_VRSERVICO,2);
      END;

      IF @STIDUTEFEPLA = 'S' BEGIN
         UPDATE EFETCLIEPME
            SET CDFILIFATU  = NULL,
                NRAPURACFAT = NULL
          WHERE CDFILCENTPME = @V_CDFILCENTPME
            AND CDFILIAL    = @V_CDFILIAL
            AND CDCLIENTE   = @P_CDCLIENTE
            AND DTEFETCLPME >= @P_DATAINI;
      END;

      UPDATE EFECLIFATMER
         SET CDFILIFATU  = NULL,
             NRAPURACFAT = NULL
       WHERE CDFILCENTPME = @V_CDFILCENTPME
         AND CDFILIAL = @V_CDFILIAL
         AND CDCLIENTE  = @P_CDCLIENTE
         AND DTEFETFATMER >= @P_DATAINI;

      FETCH NEXT FROM C_GDIRETA INTO @V_CDFILCENTPME, @V_CDFILIAL, @V_CDCLIENTE, @V_CDTIPOCARD, @V_CDSERVFILI, @V_DTFATURAM,
                                  @V_CDPRODUTO, @V_VRSERVICO, @V_QTEFETSERV, @V_NMSERVICO;

   END;
   CLOSE C_GDIRETA;
   DEALLOCATE C_GDIRETA;


END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'APURAC_GESDIRETA','5.05.035';
GO
