import {
  Metadata, Loader, IEventParam, Http, Config, IDictionary,
  dayjs as moment, I18n, Mask, DatasourceFactory,
} from '@zeedhi/core';
import {
  Select, Grid, TreeGridEditable, Form, IComponentRender, ModalService,
  Modal, GridEditable, DialogService, Button, Tabs, /* Date as ZdDate, */Number, Radio, TextInput,
  Image, FileInput, LoadingService,
} from '@zeedhi/common';
import { PmeMask } from '@/config';

export class Pla01300PratoController {
  public crudController = Loader.getInstance('CrudController');
  
  private utilities = Loader.getInstance('Utilities');
  
  private utilitiesPLA = Loader.getInstance('UtilitiesPLA');

  public gridEditController = Loader.getInstance('GridEditableController');

  public appController = Loader.getInstance('AppController');
  
  public receita = Loader.getInstance('ReceitaController');
  
  public consultaNutrientes = Loader.getInstance('Pla01305ConsultaNutrientesController');
  
  public modoPreparo = Loader.getInstance('Pla01300ModoPreparoController');

  public consultaCustos = Loader.getInstance('Pla01304ConsultaCustosController');
  
  public dadosReceita = Loader.getInstance('Pla01300DadosReceitaController');
  
  public modalAddPlate!: Modal;
  
  public modalEmissaoReceitas!: Modal;
  
  public modalGroupOperador!: Modal;
  
  public modalImport!: Modal;
  
  public modalPlates!: Modal;
  
  private recipeDest = '';

  public codeTree: IDictionary = {};

  public levelMax: any = '';

  public plateLocal: string = 'N';
  
  public plateLocalIqualPadr: string = 'N';
  
  public setNameTab: string = '';
  
  public cdGroupOperRepa: string = '';
  
  public operatorValid = false;
  
  public nrcorsafra: any = '';
  
  public nrcorinicsaf: any = '';
  
  public nrcorentrsaf: any = '';
  
  public project: string = 'PLA';
  
  public TCO: boolean = true;
  
  public setNamePlate = '';
  
  public nameComponentOperador = '';
  
  public locale = '';
  
  private prodDest: IDictionary = [];
  
  public beforeSavePlateForm: IDictionary = {};
  
  private atualiza = false;
  
  public oldCurrentRow: IDictionary = {};
  
  public plateSave: IDictionary = {};
  
  public nrFotoPratoBlob = '';
  
  public showPratoNvlCompleto = false;
  
  public get showPratoCard() {
    return !this.showPratoNvlCompleto;
  }
  
  public inicContainer() {
    // trata o projeto
    // const project = Config.env.product.id;
    // const project = localStorage.getItem('PRODUCT_ID');
    if (this.utilitiesPLA.isMerenda()) {
      this.project = 'PAE';
    } else {
      this.project = 'PLA';
    }
    
    // valida receitas TCO
    Http.post('/prato/returnParamTco', {}).then((result) => {
      const paramTco = result.data.dataset.paramTco[0];
      if (paramTco === 'N' || paramTco.IDREVRECPADQREGIAO === 'N') {
        this.TCO = false;
      }
    });
    
    // this.openModalPlates();
    this.validOperator();
  }
  
  public setFilterUnidadeDetail({ component }: IEventParam<Select>) {
    const values = {
      CDFILIAL: localStorage.getItem('CDFILIALLOGADA'),
      NMFILIAL: localStorage.getItem('NMFILIALLOGADA'),
    };
    component.datasource.data = [values];
    component.setValue(localStorage.getItem('CDFILIALLOGADA'));
  }
  
  /* public isVisibleIconPlateLocal({ row }: IDictionary) {
    return row.CDFILAUXPRAT !== 'P';
  } */
  
  private async createModalPlates() {
    this.modalPlates = await ModalService.createFromJson('planejamento/prato/modals/tabsPratos', true);
  }
  
  public openModalPlates() {
    this.createModalPlates();
    // if (!this.modalPlates) {
    // }
  }
  
  public closeModalPlates() {
    // this.modalPlates.hide();
    if (this.modalPlates) this.modalPlates.destroy();
    
    if (this.atualiza) {
      const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
      plateTree.buildTree();
      
      this.atualiza = false;
    }
    
    this.beforeSavePlateForm = {};
    this.plateSave = {};
    this.oldCurrentRow = {};
    this.showPratoNvlCompleto = false;
  }

  public changePlate({ component }: IEventParam<TreeGridEditable>) {
    const maskLevel = this.getLevelByMask(1);
    const nivelMax = maskLevel.length.toString();

    const plate = component.datasource.currentRow.CDPRATO;
    const levelPlate = component.datasource.currentRow.CDNVPRATO;
    
    if (plate) {
      if (levelPlate === nivelMax) {
        LoadingService.show(' ');
        // this.createModalPlates().then(() => {
        //   this.modalPlates.show();
        //   this.onMountedPlates();
        // });
        this.showPratoNvlCompleto = true;
        this.onMountedPlates();
      }
    }
  }
  
  public fullscreen() {
    this.modalPlates.fullscreen = true;
    this.modalPlates.cssClass = this.modalPlates.fullscreen ? 'fullscreen-fill-content' : 'modal-analise-nutricional';
  }
  
  public controlPlateLocalVis() {
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    let currentRow: any;
    if (Object.keys(this.beforeSavePlateForm).length > 0) {
      currentRow = this.beforeSavePlateForm;
    } else currentRow = plateTree.datasource.currentRow;
    const tabPratos: Tabs = Metadata.getInstance('tabPratos');

    if (currentRow.CDFILAUXPRAT !== 'P') {
      tabPratos.tabs[2].disabled = true;
    } else {
      tabPratos.tabs[2].disabled = false;
    }
  }
  
  public onMountedPlates() {
    // this.fullscreen();
    this.mountedDadosPlate();
    if (this.modalPlates || this.showPratoNvlCompleto) {
      const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
      let cdprato: any;
      if (Object.keys(this.beforeSavePlateForm).length > 0) {
        cdprato = Mask.getValueWithMask(this.beforeSavePlateForm.CDPRATO, this.utilities.maskPlate());
        this.setNamePlate = `${cdprato} | ${this.beforeSavePlateForm.NMPRATO}`;
      } else {
        cdprato = Mask.getValueWithMask(plateTree.datasource.currentRow.CDPRATO, this.utilities.maskPlate());
        this.setNamePlate = `${cdprato} | ${plateTree.datasource.currentRow.NMPRATO}`;
      }
      
      if (document.getElementsByName('tabPratos').length > 0) {
        const tabPratos: Tabs = Metadata.getInstance('tabPratos');

        if (tabPratos.activeTab !== 0 && tabPratos.activeTab === 1) this.setfilterEmbalagem();
        else if (tabPratos.activeTab !== 0 && tabPratos.activeTab === 2) this.setfilterRecipeStandard();
        else if (tabPratos.activeTab !== 0 && tabPratos.activeTab === 3) this.setfilterRecipeTpCard();
        else if (tabPratos.activeTab !== 0 && tabPratos.activeTab === 4) this.setFilterUnidadeLocal();
        else if (tabPratos.activeTab !== 0 && tabPratos.activeTab === 5) this.setFilterUnidadeService();
        else if (tabPratos.activeTab !== 0 && tabPratos.activeTab === 6) this.setfilterRecipePadraoQualidade();
        else if (tabPratos.activeTab !== 0 && tabPratos.activeTab === 7) this.changeUnityRecipeRegion();
        
        this.controlPlateLocalVis();
        tabPratos.activeTabValue = 0;
    
        this.isVisibleTabTypeMenu();
        this.visibleRecipeStandardQualityAndRegion();
      }
    }
  }
  
  public closeTabs() {
    const tabPratos: any = Metadata.getInstance('cardTabs');
    tabPratos.isVisible = false;
  }
  
  public setFilterBranch({ component }: IEventParam<Select>) {
    const conditions = [
      {
        name: 'CDOPERADOR',
        operator: '=',
        value: 'OPERADOR_LOGADO',
      },
    ];
    
    component.datasource.filter = conditions;
    component.datasource.get();
  }

  public setFilterPlateTree({ component }: IEventParam<Select>) {
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    const buttonAdd = Metadata.getInstance<Button>('addTree');
    const buttonSeach = Metadata.getInstance<Button>('searchTreeGridPlate');
    if (component.value !== null) {
      plateTree.datasource.filter = {
        CDFILIAL: component.value.CDFILIAL,
      };
      plateTree.buildTree();
      buttonAdd.disabled = false;
      buttonSeach.disabled = false;
      
      this.utilities.getParamPlaneja(component.value.CDFILIAL).then((paramplaneja: IDictionary) => {
        this.nrcorsafra = this.utilities.TColorToHex(paramplaneja?.NRCORSAFRA);
        this.nrcorinicsaf = this.utilities.TColorToHex(paramplaneja?.NRCORINICSAF);
        this.nrcorentrsaf = this.utilities.TColorToHex(paramplaneja?.NRCORENTRSAF);
        
        this.receita.getVisibilityFields();
      });
    } else {
      plateTree.datasource.filter = {};
      plateTree.datasource.data = [];
      buttonAdd.disabled = true;
      buttonSeach.disabled = true;
    }
    
    const actionsBtn = Metadata.getInstance<Button>('activatorDropDown');
    actionsBtn.disabled = this.disabledPlateActions;
    
    const filter = [
      {
        name: 'CDFILIAL',
        operator: '=',
        value: component.value?.CDFILIAL || '',
      },
    ];
    
    this.receita.produtoComponentProps.datasource.filter = filter;
    const cloneDs = DatasourceFactory.factory(this.receita.produtoComponentProps.datasource);
    cloneDs.get();
  }
  
  public addPlateForm() {
    const formDadosPlate = Metadata.getInstance<Form>('formDadosPrato');
    const rowDadosPlate = formDadosPlate.value;
    
    const cancel = Metadata.getInstance<Button>('cancelButtonDadosPlate');
    const save = Metadata.getInstance<Button>('saveButtonDadosPlate');
    cancel.disabled = false;
    save.disabled = false;
    
    this.clearAndDisableFieldsPlateForm(rowDadosPlate);
    
    const name = formDadosPlate.getChildInstance<TextInput>('NMPRATO');
    setTimeout(() => {
      if (name) name.setFocus();
    }, 100);
  }
  
  public disabledFieldsForm() {
    // const component: Tabs = Metadata.getInstance('tabPratos');
    const form = Metadata.getInstance<Form>('formDadosPrato');
    const formRow = form.value;
    
    const maskLevel = this.getLevelByMask(1);
    const levelMax = maskLevel.length;
    formRow.CDNVPRATO = '';
    
    maskLevel.forEach((row: IDictionary) => {
      if (row.caracteres === formRow.CDPRATO.length) formRow.CDNVPRATO = row.nivel;
    });
    
    if (!formRow.CDNVPRATO) {
      this.utilities.showAlert('alert', 'pme::codigoPratoInvalido', 'error');
      return;
    }
    
    const cdprato = Mask.getValueWithMask(form.value.CDPRATO, this.utilities.maskPlate());
    const tipo = form.getChildInstance<Select>('CDFILAUXPRAT');
    const un = form.getChildInstance<Select>('DSUNIDADEDP');
    const arredondTranp = form.getChildInstance<Number>('VRARREDTRANS');
    const preparo = form.getChildInstance<Select>('NMFORMAPREPARODP');
    const tempo = form.getChildInstance<Number>('QTTEMPOPRAT');
    const frequencia = form.getChildInstance<Select>('IDFREQUENCIA');
    const status = form.getChildInstance<Radio>('IDATIVO');
    // const dateInativacao = form.getChildInstance<ZdDate>('DTINATIVAUTO');
    const codPrato = form.getChildInstance<TextInput>('CDPRATO');
    
    if (tipo && un && arredondTranp && preparo && tempo && frequencia && status/* && dateInativacao */) {
      if (formRow.CDNVPRATO === levelMax) {
        tipo.disabled = false;
        un.disabled = false;
        un.addValidation('required', { message: 'pme::campoObrigatorio' });
        arredondTranp.disabled = false;
        preparo.disabled = false;
        tempo.disabled = false;
        frequencia.disabled = false;
        status.disabled = false;
        status.value = 'S';
        tipo.value = 'P';
        // dateInativacao.disabled = false;
        codPrato.addValidation('required', { message: 'pme::campoObrigatorio' });
      } else {
        tipo.disabled = true;
        tipo.value = 'P';
        un.disabled = true;
        un.removeValidation('required');
        un.value = '';
        arredondTranp.disabled = true;
        arredondTranp.value = null;
        preparo.disabled = true;
        preparo.value = '';
        tempo.disabled = true;
        tempo.value = null;
        frequencia.disabled = true;
        frequencia.value = '';
        status.disabled = true;
        status.value = 'S';
        // dateInativacao.disabled = true;
        // dateInativacao.value = '';
        this.setNamePlate = `${cdprato}`;
      }
    }
  }
  
  public clearAndDisableFieldsPlateForm(rowDadosPlate: any) {
    const form = Metadata.getInstance<Form>('formUnidade');
    const row = form.value;
    const formDadosPlate = Metadata.getInstance<Form>('formDadosPrato');
    const dsUnid = formDadosPlate.getChildInstance<Select>('DSUNIDADEDP');
    const prepare = formDadosPlate.getChildInstance<Select>('NMFORMAPREPARODP');
    const cdprato = formDadosPlate.getChildInstance<TextInput>('CDPRATO');
    const filAuxPrat = formDadosPlate.getChildInstance<Select>('CDFILAUXPRAT');
    // const dataInativacaoAuto = formDadosPlate.getChildInstance<ZdDate>('DTINATIVAUTO');
    
    this.locale = 'formPlate';
    this.generateCodePlate(rowDadosPlate, row, this.locale);
    
    const tabPratos: Tabs = Metadata.getInstance('tabPratos');
    
    tabPratos.tabs[1].disabled = true;
    tabPratos.tabs[2].disabled = true;
    tabPratos.tabs[3].disabled = true;
    tabPratos.tabs[4].disabled = true;
    tabPratos.tabs[5].disabled = true;
    tabPratos.tabs[6].disabled = true;
    tabPratos.tabs[7].disabled = true;

    rowDadosPlate.NMPRATO = '';
    rowDadosPlate.CDFILIAL = '';
    rowDadosPlate.DTINATIVAUTO = '';
    rowDadosPlate.IDATIVO = 'S';
    rowDadosPlate.IDFREQUENCIA = '';
    rowDadosPlate.QTTEMPOPRAT = null;
    rowDadosPlate.VRARREDTRANS = '0';
    dsUnid.setValue('');
    prepare.setValue('');
    
    this.setNamePlate = '';
    cdprato.disabled = false;
    filAuxPrat.disabled = false;
    // dataInativacaoAuto.disabled = false;
  }

  public addArvPlate() {
    const buttonAdd = Metadata.getInstance<Button>('addTree');
    buttonAdd.disabled = true;
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    const form = Metadata.getInstance<Form>('formUnidade');
    const row = form.value;

    row.COLUMN_NAME = 'CDGROPERREPA';
    row.ALIAS_NAME = 'ALTRECEPADRAO';
    Http.post('/prato/returnParamsAddPlate', { requestType: 'Row', row }).then((callback) => {
      if (callback && callback.data.dataset && callback.data.dataset.permission && callback.data.dataset.paramgeral.length) {
        const result = callback.data.dataset.permission.result;
        const receitaRevisada = callback.data.dataset.paramgeral[0].IDRECREVICOP;
        this.plateLocal = callback.data.dataset.paramgeral[0].IDBLOPRATLOC;
        this.plateLocalIqualPadr = callback.data.dataset.paramgeral[0].IDBLOQPRADUP;

        if (result === 'NOPERMISSION' && receitaRevisada === 'S') {
          this.utilities.showAlert('Alert', 'pme::pratoLocalOpSemPermissao', 'error');
          buttonAdd.disabled = false;
        } else {
          let currentRow: any;
          if (Object.keys(this.beforeSavePlateForm).length > 0) {
            currentRow = this.beforeSavePlateForm;
          } else currentRow = plateTree.datasource.currentRow;
          this.locale = 'treeGrid';
          this.generateCodePlate(currentRow, row, this.locale);
        }
      } else {
        this.utilities.showAlert('Alert', 'pme::paramPlanejaSemConf', 'error');
        buttonAdd.disabled = false;
      }
    });
  }
  
  public generateCodePlate(currentRow: any, row: any, locale: string) {
    const buttonAdd = Metadata.getInstance<Button>('addTree');
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    let pratoPai = currentRow.CDPRATO === undefined ? '' : currentRow.CDPRATO;
    const filAux = currentRow.CDFILAUXPRAT === undefined ? 'P' : currentRow.CDFILAUXPRAT;
    let levelPlate = currentRow.CDNVPRATO === undefined ? 0 : currentRow.CDNVPRATO;
    const unity = row.UNIDADEFORM;
    const mask: string = (Config.masks.plateMask as PmeMask).pattern;
    const maskLevel = this.getLevelByMask(1);
    const nivelMax = maskLevel.length;

    if (levelPlate === nivelMax.toString()) {
      levelPlate -= 1;
      pratoPai = pratoPai.substr(0, maskLevel[levelPlate - 1].caracteres);
    }

    if ((levelPlate === 0) || (levelPlate === 1 && pratoPai === '')) {
      levelPlate = 0;
      pratoPai = 0;
    }

    const searchLevel = this.searchLevelOpen(currentRow, plateTree);
    
    if (searchLevel === 'PSP') this.utilities.showAlert('alert', 'pme::pratoPaiInexistente', 'error');
    else {
      /* if (searchLevel.length > 0) {
        pratoPai = ((searchLevel.split('_'))[0].substr(-(maskLevel[levelPlate].caracteres))).split('.').join('.');
        levelPlate = (searchLevel.split('_'))[1];
      } */
      Http.post('/prato/searchNewCode', {
        pratoPai, filAux, levelPlate, unity, mask,
      }).then((newCode) => {
        const result = newCode.data.dataset.CODIGO[0].toString();
        let code;
        if (result === 0) code = result.padEnd(maskLevel[levelPlate].caracteres, '0');
        else code = result.padStart(maskLevel[levelPlate].caracteres, '0');
        
        if (code && locale === 'treeGrid') {
          this.openModalAddPlate(code);
          buttonAdd.disabled = false;
        } else {
          currentRow.CDPRATO = code;
          const cdprato = Mask.getValueWithMask(code, this.utilities.maskPlate());
          this.setNamePlate = `${cdprato}`;
        }
      });
    }
  }

  public searchLevelOpen(currentRowPlate: any, plateTree: TreeGridEditable) {
    let pratoPaiNivelPai = '';
    let nivelAtual = 1;
    let prato;
    
    if (currentRowPlate.CDNVPRATO > 1) nivelAtual = currentRowPlate.CDNVPRATO;

    plateTree.datasource.data.forEach((dado: IDictionary) => {
      if (currentRowPlate.CDPRATO) {
        if (dado.CDPRATO.split('.').join('') === currentRowPlate.CDPRATO.split('.').join('')) {
          prato = dado;
        }
      }
    });

    if (!prato) prato = currentRowPlate;
    
    if (prato.CDPRATONIVANTE === null && nivelAtual > 1) pratoPaiNivelPai = 'PSP';
    else {
      while (nivelAtual > 1) {
        const { currentRow } = plateTree.datasource;
        const treeRow = plateTree.treeDataStructure.getRowData(currentRow);
        // const parentPlate = treeRow.tree__parent;
        const parentPlate = treeRow;
        if (parentPlate) {
          const parentPlateOpened = treeRow.tree__opened;
          if (!parentPlateOpened) {
            pratoPaiNivelPai = nivelAtual >= 2
              ? `${parentPlate.CDPRATO}_${parentPlate.CDNVPRATO}`
              : `${parentPlate.tree__parent.CDPRATO}_${parentPlate.tree__parent.CDNVPRATO}`;
          }
        }
        prato = parentPlate;
        nivelAtual -= 1;
      }
    }
    return pratoPaiNivelPai;
  }

  public getLevelByMask(firstLevel: any) {
    const mask: string = (Config.masks.plateMask as PmeMask).pattern;
    const splitMask = mask.split('.');
    const biggestLevel = splitMask.length;

    const level: any = [];
    let objLevel = {};

    for (let i = 0; i < biggestLevel; i += 1) {
      objLevel = {
        nivel: i + firstLevel,
        caracteres: i > 0 ? level[i - 1].caracteres + splitMask[i].length : splitMask[i].length,
      };

      level.push(objLevel);
    }
    return level;
  }

  public reloadTree() {
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    const unidade = Metadata.getInstance<Form>('formUnidade');
    if (unidade.validate()) {
      plateTree.buildTree();
      if (plateTree.editing) this.cancelEditingTreeGrid();
      plateTree.selectedRows = [];
    } else plateTree.datasource.data = [];
  }

  public cancelEditingTreeGrid() {
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    plateTree.cancelEditedRows();
    const toolbarSlot = plateTree.toolbarSlot;
    toolbarSlot.forEach((e: IComponentRender) => {
      if (e.name === 'cancelButton') e.disabled = true;
      if (e.name === 'saveButton') e.disabled = true;
    });
    plateTree.buildTree();
  }

  // Funções Modal Add Plate

  private async createModalAddPlate() {
    this.modalAddPlate = await ModalService.createFromJson('planejamento/prato/modals/formAddPrato', true);
  }

  public closeModalAddPlate() {
    this.modalAddPlate.hide();
    
    // const buttonAddForm = Metadata.getInstance<Button>('addTreeDadosPlate');
    const buttonAdd = Metadata.getInstance<Button>('addTree');
    
    buttonAdd.disabled = false;
    this.plateSave = {};
    this.oldCurrentRow = {};
    // buttonAddForm.disabled = false;
  }
  
  public openModalAddPlate(code: any) {
    this.codeTree = code;
    if (this.modalAddPlate) this.modalAddPlate.destroy();
    
    this.createModalAddPlate().then(() => {
      this.modalAddPlate.show();
    });
  }

  public disabledFields() {
    const form = Metadata.getInstance<Form>('formAddPlate');
    const formRow = form.value;
    
    const maskLevel = this.getLevelByMask(1);
    const levelMax = maskLevel.length;
    formRow.CDNVPRATO = '';
    
    maskLevel.forEach((row: IDictionary) => {
      if (row.caracteres === formRow.CDPRATO.length) formRow.CDNVPRATO = row.nivel;
    });
    
    if (!formRow.CDNVPRATO) {
      this.utilities.showAlert('alert', 'pme::codigoPratoInvalido', 'error');
      return;
    }
    
    const tipo = form.getChildInstance<Select>('CDFILAUXPRAT');
    const un = form.getChildInstance<Select>('DSUNIDADE');
    const arredondTranp = form.getChildInstance<Number>('VRARREDTRANS');
    const preparo = form.getChildInstance<Select>('NMFORMAPREPARO');
    const tempo = form.getChildInstance<Number>('QTTEMPOPRAT');
    const frequencia = form.getChildInstance<Select>('IDFREQUENCIA');
    const status = form.getChildInstance<Radio>('IDATIVO');
    // const dateInativacao = form.getChildInstance<ZdDate>('DTINATIVAUTO');
    
    if (tipo && un && arredondTranp && preparo && tempo && frequencia && status /* && dateInativacao */) {
      if (formRow.CDNVPRATO === levelMax) {
        tipo.disabled = false;
        un.disabled = false;
        un.addValidation('required', { message: 'pme::campoObrigatorio' });
        un.value = '';
        arredondTranp.disabled = false;
        preparo.disabled = false;
        tempo.disabled = false;
        frequencia.disabled = false;
        status.disabled = false;
        status.value = 'S';
        tipo.value = 'P';
        // dateInativacao.disabled = false;
      } else {
        tipo.disabled = true;
        tipo.value = 'P';
        un.disabled = true;
        un.removeValidation('required');
        un.value = '';
        arredondTranp.disabled = true;
        arredondTranp.value = null;
        arredondTranp.removeValidation('maxLength');
        arredondTranp.removeValidation('min');
        preparo.disabled = true;
        preparo.value = '';
        tempo.disabled = true;
        tempo.value = null;
        tempo.removeValidation('maxLength');
        frequencia.disabled = true;
        frequencia.value = '';
        status.disabled = true;
        status.value = 'S';
        // dateInativacao.disabled = true;
        // dateInativacao.value = '';
      }
    }
  }
  
  /* public validTime() {
    const formModalPlate = Metadata.getInstance<Form>('formAddPlate');
    let time = formModalPlate.value.QTTEMPOPRAT;
    
    if (time < 1 && time !== null) {
      this.utilities.showAlert('alert', 'pme::valorTempoMaiorZero', 'warning');
      time = '';
      return false;
    }
    
    return time;
  }
  
  public validArredond() {
    const formModalPlate = Metadata.getInstance<Form>('formAddPlate');
    let arredondamento = formModalPlate.value.VRARREDTRANS;
    if (arredondamento <= 0 && arredondamento !== null) {
      this.utilities.showAlert('alert', 'pme::valorArredondMaiorZero', 'warning');
      arredondamento = '';
      return false;
    }
    
    return arredondamento;
  } */
  
  public async savePlate() {
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    const unidade = Metadata.getInstance<Form>('formUnidade').value.UNIDADEFORM.CDFILIAL;
    
    let currentRow: any;
    if (Object.keys(this.beforeSavePlateForm).length > 0) {
      currentRow = this.beforeSavePlateForm;
    } else currentRow = plateTree.datasource.currentRow;
    
    let formModalPlate: Form;
    let buttonSave: Button;
    
    if (this.locale === 'formPlate') {
      buttonSave = Metadata.getInstance<Button>('saveButtonDadosPlate');
      formModalPlate = Metadata.getInstance<Form>('formDadosPrato');
    } else {
      buttonSave = Metadata.getInstance<Button>('savePlateAdd');
      formModalPlate = Metadata.getInstance<Form>('formAddPlate');
    }
    
    buttonSave.disabled = true;
    // this.utilities.activeLoadingButton(buttonSave);
    
    const rowForm = formModalPlate.value;
    const maskLevel = this.getLevelByMask(1);
    const levelMax = maskLevel.length.toString();
    const permissaoPadrao = true; // grupo de acesso
    
    maskLevel.forEach((row: IDictionary) => {
      if (row.caracteres === rowForm.CDPRATO.length) rowForm.CDNVPRATO = row.nivel;
    });
    
    if (rowForm.CDNVPRATO.toString() === levelMax) {
      /* const time = this.validTimeForm(rowForm);
      const arred = this.validArredondForm(rowForm);
      if (time === false || arred === false) {
        if (this.locale === 'formPlate') buttonSave.disabled = false;
        else this.utilities.disableLoadingButton(buttonSave);
        return;
      }
      
      rowForm.QTTEMPOPRAT = time;
      rowForm.VRARREDTRANS = arred; */
      rowForm.CDFILIAL = unidade;
    } else {
      rowForm.CDFILIAL = '';
    }
    
    if (formModalPlate.validate()) {
      if (!rowForm.DTINATIVAUTO || moment(rowForm.DTINATIVAUTO, 'DD/MM/YYYY').isAfter(moment()) === true) {
        if ((rowForm.QTTEMPOPRAT >= 0 || !rowForm.QTTEMPOPRAT)
        && (rowForm.VRARREDTRANS >= 0 || !rowForm.VRARREDTRANS)
        ) {
          if (rowForm.IDATIVO !== null) {
            if (currentRow.CDNVPRATO < levelMax - 1 && !permissaoPadrao) {
              this.utilities.showAlert('alert', 'pme::semPermissaoAddPratoNvlComp', 'error');
              this.utilities.disableLoadingButton(buttonSave);
            } else {
              const codePlate = rowForm.CDPRATO;
              const level = rowForm.CDNVPRATO;
              if (!level) {
                this.utilities.showAlert('alert', 'pme::codigoPratoInvalido', 'error');
                this.utilities.disableLoadingButton(buttonSave);
                return;
              }
              
              let filAux = 'P';
              let CDPRATO = '';
      
              if (level > 1) CDPRATO = codePlate.substr(0, maskLevel[level - 2].caracteres);
              else CDPRATO = codePlate.substr(0, maskLevel[level - 1].caracteres);
            
              let paramPL = 'N';
              rowForm.COLUMN_NAME = 'CDGROPERREPA';
              rowForm.ALIAS_NAME = 'ALTRECEPADRAO';
              rowForm.ADDFORM = 'addForm';
              
              await Http.post('/prato/returnParamsAddPlate', { requestType: 'Row', rowForm }).then((callback) => {
                this.plateLocal = callback.data.dataset.paramgeral[0].IDBLOPRATLOC;
                this.plateLocalIqualPadr = callback.data.dataset.paramgeral[0].IDBLOQPRADUP;
              });
              
              Http.post('/prato/returnPlate', { CDPRATO, filAux, paramPL }).then((result) => { // valid dad plate exist.
                const resultPlate = result.data.dataset.PRATO;
                if (resultPlate.CDPRATO === false && level > 1) {
                  this.utilities.showAlert('alert', 'pme::pratoPaiInexistente', 'error');
                  this.utilities.disableLoadingButton(buttonSave);
                } else {
                  if (!CDPRATO && level > 1) {
                    plateTree.datasource.data.forEach((row) => {
                      if (row.CDPRATO === CDPRATO) {
                        plateTree.datasource.currentRow = row;
                      }
                    });
                  }
                  
                  CDPRATO = rowForm.CDPRATO;
                  filAux = rowForm.CDFILAUXPRAT;
                  paramPL = this.plateLocalIqualPadr;
                  // this.plateLocalIqualPadr = data.IDBLOQPRADUP;
                  // valid plate insert exist.
                  Http.post('/prato/returnPlate', { CDPRATO, filAux, paramPL }).then((codeEqual) => {
                    const resultCodeEqual = codeEqual.data.dataset.PRATO;
                    if (resultCodeEqual.CDPRATO) {
                      this.utilities.showAlert('alert', 'pme::pratoEncontradoArvore', 'error');
                      this.utilities.disableLoadingButton(buttonSave);
                    } else if (this.plateLocal === 'S') {
                      if (rowForm.CDFILAUXPRAT === 'P') {
                        this.saveRowPlate(level, levelMax, rowForm);
                      } else {
                        this.utilities.showAlert('alert', 'pme::opBloqAddPratoLocalMarcada', 'error');
                        this.utilities.disableLoadingButton(buttonSave);
                      }
                    } else this.saveRowPlate(level, levelMax, rowForm);
                  });
                }
              });
            }
          } else {
            this.utilities.showAlert('alert', 'pme::statusObrig', 'error');
            this.utilities.disableLoadingButton(buttonSave);
          }
        } else this.utilities.disableLoadingButton(buttonSave);
      } else {
        this.utilities.showAlert('alert', 'pme::dataInativacaoMaiorDataAtual', 'error');
        this.utilities.disableLoadingButton(buttonSave);
      }
    } else this.utilities.disableLoadingButton(buttonSave);
  }
  
  public calculoValidade(tempo: any, frequencia: any) {
    if (frequencia === 'H') return tempo;
    if (frequencia === 'D') return tempo * 24;
    if (frequencia === 'M') return tempo * 24 * 30;
    if (frequencia === 'A') return tempo * 24 * 30 * 12;
    return 0;
  }
  
  public saveRowPlate(level: any, levelMax: any, rowForm: any) {
    let buttonSave: Button;
    
    if (this.locale === 'formPlate') buttonSave = Metadata.getInstance<Button>('saveButtonDadosPlate');
    else buttonSave = Metadata.getInstance<Button>('savePlateAdd');
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    const form = Metadata.getInstance<Form>('formUnidade');
    const maskLevel = this.getLevelByMask(1);
    if (level < levelMax) {
      rowForm.CDFILAUXPRAT = 'P';
      rowForm.CDFILIAL = '';
      rowForm.SGUNIDADE = '';
      rowForm.VRARREDTRANS = '';
      rowForm.NRFORMAPREPARO = '';
      rowForm.QTTEMPOPRAT = '';
      rowForm.IDFREQUENCIA = '';
      rowForm.__is_new = true;
    } else {
      rowForm.CDFILIAL = form.value.UNIDADEFORM.CDFILIAL;
      if (rowForm.CDFILAUXPRAT === 'L') {
        rowForm.CDFILAUXPRAT = form.value.UNIDADEFORM.CDFILIAL;
      }
    }
    
    if (rowForm.QTTEMPOPRAT === undefined) rowForm.QTTEMPOPRAT = null;
    if (rowForm.VRARREDTRANS === undefined) rowForm.VRARREDTRANS = '0';
    rowForm.VRVALIDADE = rowForm.QTTEMPOPRAT ? this.calculoValidade(rowForm.QTTEMPOPRAT, rowForm.IDFREQUENCIA) : 0;
    rowForm.CDPRATO = rowForm.CDPRATO.split('.').join('');
    rowForm.IDATIVO = rowForm.IDATIVO === null ? 'S' : rowForm.IDATIVO;
    maskLevel.forEach((row: IDictionary) => {
      if (row.caracteres === rowForm.CDPRATO.length) rowForm.CDNVPRATO = row.nivel;
    });
    let locale: string;
    LoadingService.show(' ');
    Http.post('/prato/savePlate', { requestType: 'Row', rowForm }).then(() => {
      this.utilities.showAlert('alert', 'pme::salvoComSucesso', 'success');
      // plateTree.buildTree(); // perde referencia do prato inserido
      
      if (this.locale === 'formPlate') {
        this.plateSave = { ...rowForm };
        const tabPratos: Tabs = Metadata.getInstance('tabPratos');
        
        const cdprato = Metadata.getInstance<TextInput>('CDPRATO');
        const filAuxPrat = Metadata.getInstance<Select>('CDFILAUXPRAT');
        // const dataInativacaoAuto = Metadata.getInstance<ZdDate>('DTINATIVAUTO');
    
        tabPratos.tabs[1].disabled = false;
        tabPratos.tabs[2].disabled = false;
        tabPratos.tabs[3].disabled = false;
        tabPratos.tabs[4].disabled = false;
        tabPratos.tabs[5].disabled = false;
        tabPratos.tabs[6].disabled = false;
        tabPratos.tabs[7].disabled = false;
        
        cdprato.disabled = true;
        filAuxPrat.disabled = true;
        // dataInativacaoAuto.disabled = true;
        
        this.beforeSavePlateForm = rowForm;
        this.atualiza = true;
        
        if (level === parseFloat(levelMax)) {
          this.onMountedPlates();
        } else this.closeModalPlates();
        
        locale = '';
      } else {
        locale = this.locale;
        plateTree.buildTree();
      }
    }).catch((error: string) => {
      locale = this.locale;
      if (`${error}`.indexOf('ORA-00001') >= 0) this.utilities.showAlert('alert', 'pme::impossivelAdicionar', 'error');
      else this.utilities.showAlert('alert', `pme::${error}`, 'error');
    }).finally(() => {
      buttonSave.disabled = false;
      this.utilities.disableLoadingButton(buttonSave);
      if (this.locale === 'formPlate') {
        this.cancelForm();
        plateTree.datasource.currentRow = rowForm;
        this.locale = locale;
      } else this.closeModalAddPlate();
      LoadingService.hide();
    });
  }
  
  public updatePlate() {
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    let valid = true;
    let editedRows: IDictionary;
    try {
      editedRows = plateTree.getEditedRows();
    } catch (error) {
      editedRows = [];
      valid = false;
    }
    if (valid) {
      const buttonUpdate = Metadata.getInstance<Button>('saveButton');
      buttonUpdate.disabled = true;
      LoadingService.show(' ');
      Http.post('/prato/updatePlate', { editedRows }).then(() => {
        this.utilities.showAlert('alert', 'pme::salvoComSucesso', 'success');
        const toolbarSlot = plateTree.toolbarSlot;
        toolbarSlot.forEach((e: IComponentRender) => {
          if (e.name === 'cancelButton') e.disabled = true;
          if (e.name === 'saveButton') e.disabled = true;
        });
        
        plateTree.buildTree();
      }).catch((error: string) => {
        this.utilities.showAlert('alert', `pme::${error}`, 'error');
      }).finally(() => {
        plateTree.cancelEditedRows();
        LoadingService.hide();
      });
    }
  }
  
  public confirmDeletePlate({ component }: IEventParam<Button>) {
    const nameButton = component.name;
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    let editedRows: any = [];
    
    if (nameButton === 'excluiPlateCompl') {
      const formDadosPlate = Metadata.getInstance<Form>('formDadosPrato');
      const rowDadosPlate = formDadosPlate.value;
      
      editedRows[0] = {
        CDFILAUXPRAT: rowDadosPlate.CDFILAUXPRAT,
        CDFILIAL: rowDadosPlate.CDFILIAL,
        CDNVPRATO: rowDadosPlate.CDNVPRATO,
        CDPRATO: rowDadosPlate.CDPRATO,
        ORIGEM: 'MODAL',
      };
    } else {
      editedRows = plateTree.selectedRows;
    }
    
    if (editedRows.length === 0) {
      this.utilities.showAlert('alert', 'pme::nenhumRegSelecionado', 'warning');
    } else {
      DialogService.show({
        name: nameButton,
        type: 'warning',
        title: 'pme::atencao',
        text: 'pme::desejaExcluirRegistros',
        buttons: [
          {
            name: 'yes',
            component: 'ZdButton',
            label: 'pme::sim',
            events: { click: () => this.deleteTree(plateTree, editedRows) },
            outline: true,
          },
          {
            name: 'no',
            component: 'ZdButton',
            label: 'pme::nao',
            events: { click: () => DialogService.hide() },
          },
          {
            name: 'progressLine',
            component: 'ZdProgress',
            label: 'Progress',
            indeterminate: true,
            cssClass: 'loading-progress-line',
          },
        ],
      });
    }
  }
  
  public deleteTree(plateTree: TreeGridEditable, editedRows: any) {
    const buttonYes = Metadata.getInstance<Button>('yes');
    buttonYes.disabled = true;
    LoadingService.show(' ');
    Http.post('/prato/deletePlate', { editedRows }).then((result) => {
      if (result.data.dataset.success[0] === 'ITENS_POSSUIAM_FILHOS') {
        this.utilities.showAlert('Alert', 'pme::nemTodosExcluidoComSucesso', 'success');
      } else {
        this.utilities.showAlert('Alert', 'pme::excluidoComSucesso', 'success');
      }
      plateTree.selectedRows = [];
      plateTree.buildTree();
    }).catch((error: string) => {
      this.utilities.showAlert('alert', `pme::${error}`, 'error');
      if (error.includes('ORA-02292')) this.utilities.showAlert('alert', 'pme::ERROR_REGISTROFILHO', 'error');
    }).finally(() => {
      DialogService.hide();
      buttonYes.disabled = false;
      if (editedRows[0].ORIGEM === 'MODAL') this.closeModalPlates();
      LoadingService.hide();
    });
  }
  
  public isDetailsActionVisible({ row }: IDictionary) {
    return row.CDFILAUXPRAT !== 'P';
  }

  // Funções da aba Embalagem

  public setfilterEmbalagem() {
    const grid: GridEditable = Metadata.getInstance('gridEmbalagem');
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    let currentRow: any;
    if (Object.keys(this.beforeSavePlateForm).length > 0) {
      currentRow = this.beforeSavePlateForm;
    } else currentRow = plateTree.datasource.currentRow;
    const conditions = [
      {
        name: 'CDPRATO',
        operator: '=',
        value: currentRow.CDPRATO,
      },
      {
        name: 'CDFILAUXPRAT',
        operator: '=',
        value: currentRow.CDFILAUXPRAT,
      },
    ];
    grid.datasource.filter = conditions;
    grid.datasource.get();
  }
  
  public setValueQty({ component }: IEventParam<Select>) {
    const grid: GridEditable = Metadata.getInstance('gridEmbalagem');
    const qtContainer = component.datasource.currentRow.QTCONTAINER;

    if (qtContainer) grid.datasource.currentRow.QTPRATCONTAINER = qtContainer;
  }

  public saveEmbalagem() {
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    const grid: GridEditable = Metadata.getInstance('gridEmbalagem');
    const editedRows = grid.getEditedRows();
    let currentRow: any;
    if (editedRows.length > 0) {
      editedRows.forEach((row: IDictionary) => {
        if (row.__is_new) {
          if (Object.keys(this.beforeSavePlateForm).length > 0) {
            currentRow = this.beforeSavePlateForm;
          } else currentRow = plateTree.datasource.currentRow;
          row.CDPRATO = currentRow.CDPRATO;
          row.CDFILAUXPRAT = currentRow.CDFILAUXPRAT;
          row.CDCONTAINER = row.NMCONTAINER.CDCONTAINER;
          row.NMCONTAINER = row.NMCONTAINER.NMCONTAINER;
          row.NRORG = '';
        }
      });

      if (editedRows[0].IDPRATCONTPRI === 'S') {
        let update;
        grid.datasource.data.forEach((item: IDictionary) => {
          if (!item.__is_new && item.IDPRATCONTPRI === 'S' && item.CDCONTAINER !== editedRows[0].CDCONTAINER) {
            item.__is_new = false;
            update = item;
          }
        });

        if (update) {
          Http.post('/prato/updatePackaging', { requestType: 'Row', update }).then(() => {
            this.callSavePack(editedRows, grid);
          });
        } else this.callSavePack(editedRows, grid);
      } else this.callSavePack(editedRows, grid);
    }
  }
  
  public deleteEmbalagem({ component }: IDictionary) {
    const grid = this.utilities.returnGrid(component) as GridEditable;
    const checkedRows = grid.selectedRows;
    if (checkedRows.length === 0) this.utilities.showAlert('alert', 'pme::nenhumRegSelecionado', 'warning');
    else {
      const itemPrinc = checkedRows.filter((item) => item.IDPRATCONTPRI === 'S');
      if (itemPrinc.length > 0) this.utilities.showAlert('alert', 'pme::algumItemPrincipal', 'error');
      else {
        DialogService.show({
          name: 'excluiEmbPrat',
          type: 'warning',
          title: 'pme::atencao',
          text: 'pme::desejaExcluirRegistros',
          buttons: [
            {
              name: 'yes',
              component: 'ZdButton',
              label: 'pme::sim',
              events: { click: () => this.gridEditController.deleteCheckedRows(component) },
              outline: true,
            },
            {
              name: 'no',
              component: 'ZdButton',
              label: 'pme::nao',
              events: { click: () => DialogService.hide() },
            },
          ],
        });
      }
    }
  }

  public callSavePack(editedRows: any, grid: GridEditable) {
    this.crudController.saveRows(editedRows, 'pratocontainer', grid).then(() => {
      this.utilities.showAlert('Alert', 'pme::salvoComSucesso', 'success');
      this.gridEditController.defaultState(grid);
      // this.gridEditController.reload({ grid });
    }).catch((error: string) => {
      this.utilities.showAlert('alert', `pme::${error}`, 'error');
    });
  }
  
  public addEmbalagem({ component }: IDictionary) {
    const grid = this.utilities.returnGrid(component) as GridEditable;
    const newId = '';
    const uniqueKey = grid.datasource.uniqueKey;
    
    if (!this.gridEditController.newRow) {
      grid.addNewRow({ [uniqueKey]: newId, __is_new: true, IDPRATCONTPRI: 'S' }, 'start');
      this.gridEditController.newRow = true;
      if (!grid.editing) {
        grid.editing = true;
        if (!this.gridEditController.isInlineEditing) this.gridEditController.onInlineEdit({ component: grid });
      }
      
      /* Coloca foco na primeira coluna do grid. Ficar atento a coluna invisível */
      const columnName = grid?.columns[0]?.name;
      setTimeout(() => {
        (grid.getComponent(newId, columnName) as IDictionary).setFocus();
      }, 100);
    }
  }
  
  public setFocus({ component }: IEventParam<TextInput>) {
    setTimeout(() => {
      component.setFocus();
    }, 100);
  }
  
  // SetForm Dados do Prato
  
  public mountedDadosPlate() {
    let currentRow: any;
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    if (Object.keys(this.beforeSavePlateForm).length > 0) {
      currentRow = this.beforeSavePlateForm;
    } else currentRow = plateTree.datasource.currentRow;
    
    if (Object.keys(this.plateSave).length === 0) this.oldCurrentRow = currentRow;
    else currentRow = this.plateSave;
    
    // rowDadosPlate.CDFILIAL = currentRow.CDFILIAL;
    const row = {
      CDFILIAL: currentRow.CDFILIAL,
      CDFILAUXPRAT: currentRow.CDFILAUXPRAT,
      CDPRATO: currentRow.CDPRATO,
    };
    
    Http.post('/prato/resultDadosPlate', { requestType: 'Row', row }).then((result) => {
      const retorno = result.data.dataset.result[0];
      if (retorno.CDFILAUXPRAT === retorno.CDFILIAL) retorno.CDFILAUXPRAT = 'L';
      if (retorno.DTINATIVAUTO !== null) retorno.DTINATIVAUTO = moment(retorno.DTINATIVAUTO, 'DD/MM/YYYY');
      
      const formDadosPlate = Metadata.getInstance<Form>('formDadosPrato');
      const rowDadosPlate = formDadosPlate.value;
    
      rowDadosPlate.CDFILAUXPRAT = retorno.CDFILAUXPRAT;
      rowDadosPlate.CDPRATO = retorno.CDPRATO;
      rowDadosPlate.NMPRATO = retorno.NMPRATO;
      rowDadosPlate.CDNVPRATO = retorno.CDNVPRATO;
      rowDadosPlate.CDFILIAL = retorno.CDFILIAL;
      rowDadosPlate.DTINATIVAUTO = retorno.DTINATIVAUTO;
      rowDadosPlate.IDATIVO = retorno.IDATIVO;
      rowDadosPlate.IDFREQUENCIA = retorno.IDFREQUENCIA;
      rowDadosPlate.QTTEMPOPRAT = retorno.QTTEMPOPRAT;
      rowDadosPlate.VRARREDTRANS = retorno.VRARREDTRANS;
      
      const dsUnid = Metadata.getInstance<Select>('DSUNIDADEDP');
      const prepare = Metadata.getInstance<Select>('NMFORMAPREPARODP');
      const dsUnidade = {
        SGUNIDADE: retorno.SGUNIDADE,
        DSUNIDADE: retorno.DSUNIDADE,
      };
      // dsUnid.datasource.data = [dsUnidade];
      dsUnid.datasource.data = this.utilities.merge(dsUnid.datasource.data, [dsUnidade],
        (a: any, b: any) => a.SGUNIDADE === b.SGUNIDADE);
      dsUnid.setValue(retorno.SGUNIDADE);
      if (retorno.NRFORMAPREPARO) {
        const formaPreparo = {
          NRFORMAPREPARO: retorno.NRFORMAPREPARO,
          NMFORMAPREPARO: retorno.NMFORMAPREPARO,
        };
        // prepare.datasource.data = [formaPreparo];
        prepare.datasource.data = this.utilities.merge(prepare.datasource.data, [formaPreparo],
          (a: any, b: any) => a.NRFORMAPREPARO === b.NRFORMAPREPARO);
        prepare.setValue(retorno.NRFORMAPREPARO);
      } else prepare.setValue('');
      
      formDadosPlate.validate();
      
      const cdprato = Mask.getValueWithMask(retorno.CDPRATO, this.utilities.maskPlate());
      this.setNamePlate = `${cdprato} | ${retorno.NMPRATO}`;
      LoadingService.hide();
    });
    
    /* const cancel = Metadata.getInstance<Button>('cancelButtonDadosPlate');
    const save = Metadata.getInstance<Button>('saveButtonDadosPlate');
    cancel.disabled = true;
    save.disabled = true; */
  }
  
  public disableButtonsDadosPlate() {
    const cancel = Metadata.getInstance<Button>('cancelButtonDadosPlate');
    const save = Metadata.getInstance<Button>('saveButtonDadosPlate');
    cancel.disabled = false;
    save.disabled = false;
  }
  
  public cancelForm() {
    this.mountedDadosPlate();
    const cancel = Metadata.getInstance<Button>('cancelButtonDadosPlate');
    const save = Metadata.getInstance<Button>('saveButtonDadosPlate');
    cancel.disabled = true;
    save.disabled = true;
    
    const form = Metadata.getInstance<Form>('formDadosPrato');
    const cdprato = form.getChildInstance<TextInput>('CDPRATO');
    const tipo = form.getChildInstance<Select>('CDFILAUXPRAT');
    cdprato.disabled = true;
    tipo.disabled = true;
    
    this.enableTabs();
  }
  
  public enableTabs() {
    const tabPratos: Tabs = Metadata.getInstance('tabPratos');
    tabPratos.tabs[1].disabled = false;
    tabPratos.tabs[2].disabled = false;
    tabPratos.tabs[3].disabled = false;
    tabPratos.tabs[4].disabled = false;
    tabPratos.tabs[5].disabled = false;
    tabPratos.tabs[6].disabled = false;
    tabPratos.tabs[7].disabled = false;
  }
  
  public updateDadosPlate() {
    if (this.locale === 'formPlate') this.savePlate();
    else {
      const buttonUpdate = Metadata.getInstance<Button>('saveButtonDadosPlate');
      buttonUpdate.disabled = true;
      const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
      const formDadosPlate = Metadata.getInstance<Form>('formDadosPrato');
      const rowDadosPlate = formDadosPlate.value;
      if (Object.keys(this.beforeSavePlateForm).length > 0) {
        rowDadosPlate.CDFILAUXPRAT_UPDATE = this.beforeSavePlateForm.CDFILAUXPRAT;
      } else rowDadosPlate.CDFILAUXPRAT_UPDATE = plateTree.datasource.currentRow.CDFILAUXPRAT;
      
      /* const time = this.validTimeForm(rowDadosPlate);
      const arred = this.validArredondForm(rowDadosPlate);
      if (time === false || arred === false) {
        return;
      }
     
      rowDadosPlate.QTTEMPOPRAT = time;
      rowDadosPlate.VRARREDTRANS = arred; */
      
      if (typeof rowDadosPlate.DTINATIVAUTO === 'object' && rowDadosPlate.DTINATIVAUTO !== null) {
        rowDadosPlate.DTINATIVAUTO = rowDadosPlate.DTINATIVAUTO.format('DD/MM/YYYY');
      }
      
      if ((rowDadosPlate.QTTEMPOPRAT >= 0 || !rowDadosPlate.QTTEMPOPRAT)
        && (rowDadosPlate.VRARREDTRANS >= 0 || !rowDadosPlate.VRARREDTRANS)
      ) {
        if (!rowDadosPlate.DTINATIVAUTO || moment(rowDadosPlate.DTINATIVAUTO, 'DD/MM/YYYY').isAfter(moment()) === true) {
          if (rowDadosPlate.CDPRATO !== null && formDadosPlate.validate()) {
            LoadingService.show(' ');
            
            Http.post('/prato/updateDadosPlate', { rowDadosPlate }).then(() => {
              this.utilities.showAlert('alert', 'pme::salvoComSucesso', 'success');
              let currentRow: any;
              if (Object.keys(this.beforeSavePlateForm).length > 0) {
                currentRow = this.beforeSavePlateForm;
              } else currentRow = plateTree.datasource.currentRow;
              if (currentRow.NMPRATO !== rowDadosPlate.NMPRATO) {
                const cdprato = Mask.getValueWithMask(currentRow.CDPRATO, this.utilities.maskPlate());
                this.setNamePlate = `${cdprato} | ${rowDadosPlate.NMPRATO}`;
                // this.mountedDadosPlate();
                // plateTree.buildTree();
                this.atualiza = true;
              }
            }).catch((error: string) => {
              this.utilities.showAlert('alert', `pme::${error}`, 'error');
            }).finally(() => {
              // this.mountedDadosPlate();
              this.cancelForm();
              plateTree.cancelEditedRows();
              LoadingService.hide();
            });
          }
        } else {
          this.utilities.showAlert('alert', 'pme::dataInativacaoMaiorDataAtual', 'error');
          rowDadosPlate.DTINATIVAUTO = '';
        }
      } else this.utilities.showAlert('alert', 'pme::valorTempoArrendonZero', 'error');
    }
  }
  
  /* public validTimeForm(rowDadosPlate: any) {
    let time = rowDadosPlate.QTTEMPOPRAT;
    
    if (time === undefined) time = '';
    
    if (time < 1 && time !== null) {
      this.utilities.showAlert('alert', 'pme::valorTempoMaiorZero', 'warning');
      time = '';
      return false;
    }
    
    return time;
  } */
  
  public validArredondForm(rowDadosPlate: any) {
    let arredondamento = rowDadosPlate.VRARREDTRANS;
    
    if (arredondamento === undefined) arredondamento = '';
    
    if (arredondamento <= 0 && arredondamento !== null) {
      this.utilities.showAlert('alert', 'pme::valorArredondMaiorZero', 'warning');
      arredondamento = '';
      return false;
    }
    
    return arredondamento;
  }
  
  // Receitas
  
  public setFilterUnidadeLocal() {
    const formUnidade = Metadata.getInstance<Form>('formUnidade');
    const unidLocal = Metadata.getInstance<Select>('BRANCH_LOCAL');
    const values = {
      CDFILIAL: formUnidade.value.UNIDADEFORM.CDFILIAL,
      NMFILIAL: formUnidade.value.UNIDADEFORM.NMFILIAL,
    };
    unidLocal.datasource.data = [values];
    unidLocal.setValue(formUnidade.value.UNIDADEFORM.CDFILIAL);
  }
  
  public setFilterUnidadeService() {
    const formUnidade = Metadata.getInstance<Form>('formUnidade');
    const unidLService = Metadata.getInstance<Select>('BRANCH_SERVICE');
    const values = {
      CDFILIAL: formUnidade.value.UNIDADEFORM.CDFILIAL,
      NMFILIAL: formUnidade.value.UNIDADEFORM.NMFILIAL,
    };
    unidLService.datasource.data = [values];
    unidLService.setValue(formUnidade.value.UNIDADEFORM.CDFILIAL);
  }
  
  // Receita Padrão
  
  public setfilterRecipeStandard() {
    if (document.getElementsByName('RECIPE_STANDARD').length > 0) {
      const grid: GridEditable = Metadata.getInstance('RECIPE_STANDARD');
      const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
      let currentRow: any;
      if (Object.keys(this.beforeSavePlateForm).length > 0) {
        currentRow = this.beforeSavePlateForm;
      } else currentRow = plateTree.datasource.currentRow;
      const conditions = [
        {
          name: 'CDPRATO',
          operator: '=',
          value: currentRow.CDPRATO,
        },
        {
          name: 'CDFILAUXPRAT',
          operator: '=',
          value: currentRow.CDFILAUXPRAT,
        },
      ];
      grid.datasource.filter = conditions;
      grid.datasource.get().then(() => {
        // this.loadStandardRecipeData(conditions);
        const addButton: Button = grid.getChildInstance('addButtonPad');
        addButton.disabled = false;
        // this.enabledTabs();
      });
    }
  }
  
  public saveRecipeStandard({ component }: IDictionary) {
    const grid: GridEditable = this.utilities.returnGrid(component) as GridEditable;
    const form = Metadata.getInstance<Form>('formRecipeStandard');
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    let currentRow: any;
    if (Object.keys(this.beforeSavePlateForm).length > 0) {
      currentRow = this.beforeSavePlateForm;
    } else currentRow = plateTree.datasource.currentRow;
    
    if (form.validate()) {
      const rows: IDictionary = grid.datasource.data.filter((e: IDictionary) => e.EDITED);
      let ctrlEstoq = true;
      let active = true;
      let validHour = true;
      let validLimNegative = true;

      rows.forEach((e: IDictionary) => {
        e.CDPRATO = currentRow.CDPRATO;
        e.CDFILAUXPRAT = currentRow.CDFILAUXPRAT;
        // e.SGUNIDADE = e.SGUNIDPROD;
        e.QTLIMSEGPADR = e.QTLIMSEGPADR || null;
        if (e.QTLIMSEGPADR < 0) validLimNegative = false;
        e.QTCOMPLPRODPADR = e.QTCOMPLPRODPADR || 0;
        e.CDAPRERECE = e.CDAPRERECE || null;
        // if (e.__is_new) e.CDPRODUTO = e.CDPRODUTOAUX;
        if (e.__is_new && e.IDCNTRESTOQ !== 'S') ctrlEstoq = false;
        if (e.__is_new && e.IDPRODATIV !== 'A') active = false;
        if (e.HRTEMPPREPPR && !this.utilities.timeIsValid(e.HRTEMPPREPPR)) validHour = false;
        e.HRTEMPPREPPR = this.utilities.formatHour(e.HRTEMPPREPPR, false);
        if (e.originalRow) delete e.originalRow;
        if (e.OLDROW) delete e.OLDROW;
      });

      if (!validLimNegative) this.utilities.showAlert('diasLimSegNegative', 'pme::diasLimSegNegative', 'red');
      else if (this.receita.saveIsValid(validHour, ctrlEstoq, active)) {
        this.receita.callSave('/saveRecipeStandard', rows, grid);
      }
    } else this.utilities.showAlert('alert', 'pme::verificarCamposObg', 'error');
  }
  
  public getFilterProd() {
    const unidade = Metadata.getInstance<Select>('UNIDADEFORM');
    return [
      {
        name: 'CDFILIAL',
        operator: '=',
        value: unidade.value.CDFILIAL,
      },
    ];
  }
  
  // Receita Local
  
  public setFilterRecipeLocal() {
    const tab = this.setNameTab;
    if (document.getElementsByName('RECIPE_LOCAL').length > 0) {
      const form = Metadata.getInstance<Form>('FORM_LOCAL');
      const unidade = form.value.BRANCH_LOCAL?.CDFILIAL;
      const tabLocal = Metadata.getInstance<Tabs>('subTabReceitaLocal');
      
      let grid: any;
      if (tab === 'subTabReceitaLocal') {
        if (tabLocal.activeTab === 0) grid = Metadata.getInstance<GridEditable>('RECIPE_LOCAL');
        else if (tabLocal.activeTab === 2) grid = Metadata.getInstance<Grid>('CONSULTACUSTOS-Local');
        else if (tabLocal.activeTab === 3) grid = Metadata.getInstance<Grid>('CONSULTANUTRIENTES-Local');
        else if (tabLocal.activeTab === 4) grid = Metadata.getInstance<Grid>('gridModoPreparoLocal');
        else if (tabLocal.activeTab === 5) this.setImageSrc();
      }
      
      const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
      let currentRow: any;
      if (Object.keys(this.beforeSavePlateForm).length > 0) {
        currentRow = this.beforeSavePlateForm;
      } else currentRow = plateTree.datasource.currentRow;
      
      if (tab === 'subTabReceitaLocal') {
        const tabs = Metadata.getInstance<Tabs>('subTabReceitaLocal');
        if (tabs.activeTab === 0) {
          const conditions = [
            {
              name: 'CDPRATO',
              operator: '=',
              value: currentRow.CDPRATO,
            },
            {
              name: 'CDFILIAL',
              operator: '=',
              value: unidade,
            },
            {
              name: 'CDFILAUXPRAT',
              operator: '=',
              value: currentRow.CDFILAUXPRAT,
            },
          ];
          grid.datasource.filter = conditions;
        }
        
        if (!unidade) {
          if (tabLocal.activeTab === 0 || tabLocal.activeTab === 2 || tabLocal.activeTab === 3 || tabLocal.activeTab === 4) {
            const addButton: Button = grid.getChildInstance('addButton');
            grid.datasource.data = [];
            addButton.disabled = true;
          } else if (tabLocal.activeTab === 1) this.dadosReceita.setValuesRecipe();
        } else if (unidade) {
          if (tabLocal.activeTab === 0 || tabLocal.activeTab === 2 || tabLocal.activeTab === 3 || tabLocal.activeTab === 4) {
            grid.datasource.get().then(() => {
              const addButton: Button = grid.getChildInstance('addButton');
              addButton.disabled = false;
              if (tabs.activeTab === 2) this.consultaCustos.filterPlatesGrid();
              else if (tabs.activeTab === 3) this.consultaNutrientes.filterNutrientesGrid();
              else if (tabs.activeTab === 4) this.modoPreparo.formatDatasourceModoPreparo(grid);
            });
          } else if (tabs.activeTab === 1) this.dadosReceita.setValuesRecipe();
        }
      }
    }
  }
  
  public saveRecipeLocal({ component }: IDictionary) {
    const grid: GridEditable = this.utilities.returnGrid(component) as GridEditable;
    const form = Metadata.getInstance<Form>('formRecipeLocal');
    const formUnidLocal = Metadata.getInstance<Form>('FORM_LOCAL');
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    let currentRow: any;
    if (Object.keys(this.beforeSavePlateForm).length > 0) {
      currentRow = this.beforeSavePlateForm;
    } else currentRow = plateTree.datasource.currentRow;
    
    if (form.validate()) {
      const rows: IDictionary = grid.datasource.data.filter((e: IDictionary) => e.EDITED);
      let ctrlEstoq = true;
      let active = true;
      let validHour = true;
      let validLimNegative = true;

      rows.forEach((e: IDictionary) => {
        e.CDFILIAL = formUnidLocal.value.BRANCH_LOCAL.CDFILIAL;
        e.CDPRATO = currentRow.CDPRATO;
        e.CDFILAUXPRAT = currentRow.CDFILAUXPRAT;
        // e.SGUNIDADE = e.SGUNIDPROD;
        e.QTLIMSEGFILI = e.QTLIMSEGFILI || null;
        if (e.QTLIMSEGFILI < 0) validLimNegative = false;
        e.QTCOMPLPRODFILI = e.QTCOMPLPRODFILI || 0;
        e.CDAPRERECE = e.CDAPRERECE || null;
        // if (e.__is_new) e.CDPRODUTO = e.CDPRODUTOAUX;
        if (e.__is_new && e.IDCNTRESTOQ !== 'S') ctrlEstoq = false;
        if (e.__is_new && e.IDPRODATIV !== 'A') active = false;
        if (e.HRTEMPPREPLO && !this.utilities.timeIsValid(e.HRTEMPPREPLO)) validHour = false;
        e.HRTEMPPREPLO = this.utilities.formatHour(e.HRTEMPPREPLO, false);
        if (e.originalRow) delete e.originalRow;
        if (e.OLDROW) delete e.OLDROW;
      });
      
      if (!validLimNegative) this.utilities.showAlert('diasLimSegNegative', 'pme::diasLimSegNegative', 'red');
      else if (this.receita.saveIsValid(validHour, ctrlEstoq, active)) this.receita.callSave('/saveRecipeLocal', rows, grid);
    } else this.utilities.showAlert('alert', 'pme::verificarCamposObg', 'error');
  }
  
  // Receita Serviço
  
  public changeUnityRecipeServ() {
    const tab = this.setNameTab;
    let grid: any;
    if (tab === 'subTabReceitaServico') {
      if (document.getElementsByName('RECIPE_SERVICE').length > 0) {
        const tabServico = Metadata.getInstance<Tabs>('subTabReceitaServico');
        if (tabServico.activeTab === 0) grid = Metadata.getInstance<GridEditable>('RECIPE_SERVICE');
        else if (tabServico.activeTab === 2) grid = Metadata.getInstance<Grid>('CONSULTACUSTOS-Servico');
        else if (tabServico.activeTab === 3) grid = Metadata.getInstance<Grid>('CONSULTANUTRIENTES-Servico');
        else if (tabServico.activeTab === 4) grid = Metadata.getInstance<Grid>('gridModoPreparoServico');
        else if (tabServico.activeTab === 5) this.setImageSrc();
        
        const serv = Metadata.getInstance<Select>('SERVICE');
        serv.setValue('');
        grid.datasource.data = [];
      }
    }
  }
  
  public setFilterRecipeService() {
    const tab = this.setNameTab;
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    let currentRow: any;
    if (Object.keys(this.beforeSavePlateForm).length > 0) {
      currentRow = this.beforeSavePlateForm;
    } else currentRow = plateTree.datasource.currentRow;
    
    const tabs = Metadata.getInstance<Tabs>('subTabReceitaServico');
    
    if (document.getElementsByName('RECIPE_SERVICE').length > 0) {
      let grid: any;
      if (tab === 'subTabReceitaServico') {
        if (tabs.activeTab === 0) grid = Metadata.getInstance<GridEditable>('RECIPE_SERVICE');
        else if (tabs.activeTab === 2) grid = Metadata.getInstance<Grid>('CONSULTACUSTOS-Servico');
        else if (tabs.activeTab === 3) grid = Metadata.getInstance<Grid>('CONSULTANUTRIENTES-Servico');
        else if (tabs.activeTab === 4) grid = Metadata.getInstance<Grid>('gridModoPreparoServico');
        else if (tabs.activeTab === 5) this.setImageSrc();
      }
      
      const form = Metadata.getInstance<Form>('FORM_SERVICE');
      const unidade = form.value.BRANCH_SERVICE?.CDFILIAL;
      const servico = form.value.SERVICE?.CDSERVFILI;
      
      if (form.validate()) {
        if (tabs.activeTab === 0) {
          const conditions = [
            {
              name: 'CDPRATO',
              operator: '=',
              value: currentRow.CDPRATO,
            },
            {
              name: 'CDFILIAL',
              operator: '=',
              value: unidade,
            },
            {
              name: 'CDSERVFILI',
              operator: '=',
              value: servico,
            },
            {
              name: 'CDFILAUXPRAT',
              operator: '=',
              value: currentRow.CDFILAUXPRAT,
            },
          ];
          
          grid.datasource.filter = conditions;
        }
      }
        
      if (!unidade || !servico) {
        if (tabs.activeTab === 0 || tabs.activeTab === 2 || tabs.activeTab === 3
            || tabs.activeTab === 4) {
          const addButton: Button = grid.getChildInstance('addButton');
          grid.datasource.data = [];
          grid.datasource.filter = [];
          addButton.disabled = true;
        } else if (tabs.activeTab === 1) this.dadosReceita.setValuesRecipe();
      } else if (servico) {
        if (tabs.activeTab === 0 || tabs.activeTab === 2
            || tabs.activeTab === 3) {
          const addButton: Button = grid.getChildInstance('addButton');
          grid.datasource.get().then(() => {
            addButton.disabled = false;
            if (tabs.activeTab === 2) this.consultaCustos.filterPlatesGrid();
            else if (tabs.activeTab === 3) this.consultaNutrientes.filterNutrientesGrid();
          });
        } else if (tabs.activeTab === 4) this.modoPreparo.setFilters();
        else if (tabs.activeTab === 1) this.dadosReceita.setValuesRecipe();
      }
    }
  }
  
  public saveRecipeService({ component }: IDictionary) {
    const grid: GridEditable = this.utilities.returnGrid(component) as GridEditable;
    const form = Metadata.getInstance<Form>('formRecipeService');
    const formService = Metadata.getInstance<Form>('FORM_SERVICE');
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    let currentRow: any;
    if (Object.keys(this.beforeSavePlateForm).length > 0) {
      currentRow = this.beforeSavePlateForm;
    } else currentRow = plateTree.datasource.currentRow;
    
    if (form.validate()) {
      const rows: IDictionary = grid.datasource.data.filter((e: IDictionary) => e.EDITED);
      let ctrlEstoq = true;
      let active = true;
      let validHour = true;
      let validLimNegative = true;

      rows.forEach((e: IDictionary) => {
        e.CDFILIAL = formService.value.BRANCH_SERVICE.CDFILIAL;
        e.CDSERVFILI = formService.value.SERVICE.CDSERVFILI;
        e.CDFILAUXPRAT = currentRow.CDFILAUXPRAT;
        e.CDPRATO = currentRow.CDPRATO;
        // e.SGUNIDADE = e.SGUNIDADE;
        e.QTLIMSEGSERV = e.QTLIMSEGSERV || null;
        if (e.QTLIMSEGSERV < 0) validLimNegative = false;
        e.QTCOMPLPRODSERV = e.QTCOMPLPRODSERV || 0;
        e.CDAPRERECE = e.CDAPRERECE || null;
        // if (e.__is_new) e.CDPRODUTO = e.CDPRODUTOAUX;
        if (e.__is_new && e.IDCNTRESTOQ !== 'S') ctrlEstoq = false;
        if (e.__is_new && e.IDPRODATIV !== 'A') active = false;
        if (e.HRTEMPPREPSE && !this.utilities.timeIsValid(e.HRTEMPPREPSE)) validHour = false;
        e.HRTEMPPREPSE = this.utilities.formatHour(e.HRTEMPPREPSE, false);
        if (e.originalRow) delete e.originalRow;
        if (e.OLDROW) delete e.OLDROW;
      });
      
      if (!validLimNegative) this.utilities.showAlert('diasLimSegNegative', 'pme::diasLimSegNegative', 'red');
      else if (this.receita.saveIsValid(validHour, ctrlEstoq, active)) {
        this.receita.callSave('/saveRecipeService', rows, grid);
      }
    } else this.utilities.showAlert('alert', 'pme::verificarCamposObg', 'error');
  }
  
  //  Receita Tipo de Cardápio
  
  public isVisibleTabTypeMenu() {
    const tabPlate = Metadata.getInstance<Tabs>('tabPratos');
    const tabTypeMenu = tabPlate.tabs.find((column: IDictionary) => column.name === 'tabReceitaTipoCardapio');
    if (tabTypeMenu) {
      if (this.project === 'PAE') tabTypeMenu.isVisible = true;
      else tabTypeMenu.isVisible = false;
    }
  }
  
  public setfilterRecipeTpCard() {
    const tab = this.setNameTab;
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    let currentRow: any;
    if (Object.keys(this.beforeSavePlateForm).length > 0) {
      currentRow = this.beforeSavePlateForm;
    } else currentRow = plateTree.datasource.currentRow;
    const tabTpCard = Metadata.getInstance<Tabs>('subTabReceitaTipoCard');
    
    if (document.getElementsByName('RECIPE_TIPOCARD').length > 0) {
      let grid: any;
      if (tab === 'subTabReceitaTipoCard') {
        if (tabTpCard.activeTab === 0) grid = Metadata.getInstance<GridEditable>('RECIPE_TIPOCARD');
        else if (tabTpCard.activeTab === 2) grid = Metadata.getInstance<Grid>('CONSULTACUSTOS-TipoCard');
        else if (tabTpCard.activeTab === 3) grid = Metadata.getInstance<Grid>('CONSULTANUTRIENTES-TipoCard');
        else if (tabTpCard.activeTab === 4) grid = Metadata.getInstance<Grid>('gridModoPreparoTipoCard');
        else if (tabTpCard.activeTab === 5) this.setImageSrc();
      }
      
      const formTpCard = Metadata.getInstance<Form>('FORM_TIPOCARD');
      const tpCard = formTpCard.value.TIPOCARD?.CDTIPOCARD;
      
      if (tab === 'subTabReceitaTipoCard') {
        const tabs = Metadata.getInstance<Tabs>('subTabReceitaTipoCard');
        
        if (tabs.activeTab === 0) {
          const conditions = [
            {
              name: 'P_CDPRATO',
              operator: '=',
              value: currentRow.CDPRATO,
            },
            {
              name: 'P_CDFILAUXPRAT',
              operator: '=',
              value: currentRow.CDFILAUXPRAT,
            },
            {
              name: 'P_CDFILCENTPME',
              operator: '=',
              value: this.appController.getCdCentral(),
            },
            {
              name: 'P_CDTIPOCARD',
              operator: '=',
              value: tpCard,
            },
          ];
      
          grid.datasource.filter = conditions;
        }
        if (!tpCard) {
          if (tabTpCard.activeTab === 0 || tabTpCard.activeTab === 2 || tabTpCard.activeTab === 3
              || tabTpCard.activeTab === 4) {
            const addButton: Button = grid.getChildInstance('addButton');
            grid.datasource.data = [];
            addButton.disabled = true;
          } else if (tabTpCard.activeTab === 1) this.dadosReceita.setValuesRecipe();
        } else if (tpCard) {
          if (tabTpCard.activeTab === 0 || tabTpCard.activeTab === 2
              || tabTpCard.activeTab === 3) {
            const addButton: Button = grid.getChildInstance('addButton');
            grid.datasource.get().then(() => {
              addButton.disabled = false;
              if (tabs.activeTab === 2) this.consultaCustos.filterPlatesGrid();
              else if (tabs.activeTab === 3) this.consultaNutrientes.filterNutrientesGrid();
            });
          } else if (tabTpCard.activeTab === 4) this.modoPreparo.setFilters();
          else if (tabs.activeTab === 1) this.dadosReceita.setValuesRecipe();
        }
      }
    }
  }
  
  public saveRecipeTpCard({ component }: IDictionary) {
    const grid: GridEditable = this.utilities.returnGrid(component) as GridEditable;
    const form = Metadata.getInstance<Form>('formRecipeTpcard');
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    let currentRow: any;
    if (Object.keys(this.beforeSavePlateForm).length > 0) {
      currentRow = this.beforeSavePlateForm;
    } else currentRow = plateTree.datasource.currentRow;
    const formTpCard = Metadata.getInstance<Form>('FORM_TIPOCARD');
    
    if (form.validate()) {
      const rows: IDictionary = grid.datasource.data.filter((e: IDictionary) => e.EDITED);
      let ctrlEstoq = true;
      let active = true;
      let validHour = true;

      rows.forEach((e: IDictionary) => {
        e.CDTIPOCARD = formTpCard.value.TIPOCARD.CDTIPOCARD;
        e.CDPRATO = currentRow.CDPRATO;
        e.CDFILAUXPRAT = currentRow.CDFILAUXPRAT;
        // e.SGUNIDADE = e.SGUNIDPROD;
        e.CDAPRERECE = e.CDAPRERECE || null;
        // if (e.__is_new) e.CDPRODUTO = e.CDPRODUTOAUX;
        if (e.__is_new && e.IDCNTRESTOQ !== 'S') ctrlEstoq = false;
        if (e.__is_new && e.IDPRODATIV !== 'A') active = false;
        if (e.HRTEMPPREPPRTP && !this.utilities.timeIsValid(e.HRTEMPPREPPRTP)) validHour = false;
        e.HRTEMPPREPPRTP = this.utilities.formatHour(e.HRTEMPPREPPRTP, false);
        e.CDFILCENTPME = this.appController.getCdCentral();
        if (e.originalRow) delete e.originalRow;
        if (e.OLDROW) delete e.OLDROW;
      });

      if (this.receita.saveIsValid(validHour, ctrlEstoq, active)) this.receita.callSave('/saveRecipeTpCard', rows, grid);
    } else this.utilities.showAlert('alert', 'pme::verificarCamposObg', 'error');
  }
  
  // Receita Padrão de Qualidade e Região
  
  public visibleRecipeStandardQualityAndRegion() {
    const tabPlate = Metadata.getInstance<Tabs>('tabPratos');
    const tabStandardQuality = tabPlate.tabs.find((column: IDictionary) => column.name === 'tabReceitaPadraoQualidade');
    const tabRegion = tabPlate.tabs.find((column: IDictionary) => column.name === 'tabReceitaRegiao');
    if (tabStandardQuality && tabRegion) {
      if (this.TCO) {
        tabStandardQuality.isVisible = true;
        tabRegion.isVisible = true;
      } else {
        tabStandardQuality.isVisible = false;
        tabRegion.isVisible = false;
      }
    }
  }
  
  public changeUnityRecipeRegion() {
    const tab = this.setNameTab;
    let grid: any;
    if (tab === 'subTabReceitaRegiao') {
      const tabRegiao = Metadata.getInstance<Tabs>('subTabReceitaRegiao');
      if (tabRegiao.activeTab === 0) grid = Metadata.getInstance<GridEditable>('RECIPE_REGION');
      else if (tabRegiao.activeTab === 2) grid = Metadata.getInstance<Grid>('CONSULTANUTRIENTES-Regiao');
      else if (tabRegiao.activeTab === 3) grid = Metadata.getInstance<Grid>('gridModoPreparoRegiao');
    }
    const regiao = Metadata.getInstance<Select>('NMREGIAO');
    regiao.setValue('');
    grid.datasource.data = [];
  }
  
  public setfilterRecipeRegion() {
    const tab = this.setNameTab;
    if (document.getElementsByName('RECIPE_REGION').length > 0) {
      // const grid: GridEditable = Metadata.getInstance('RECIPE_REGION');
      const form = Metadata.getInstance<Form>('FORM_REGIAO');
      const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
      let currentRow: any;
      if (Object.keys(this.beforeSavePlateForm).length > 0) {
        currentRow = this.beforeSavePlateForm;
      } else currentRow = plateTree.datasource.currentRow;
      const tabRegiao = Metadata.getInstance<Tabs>('subTabReceitaRegiao');
      
      let grid: any;
      if (tab === 'subTabReceitaRegiao') {
        if (tabRegiao.activeTab === 0) grid = Metadata.getInstance<GridEditable>('RECIPE_REGION');
        else if (tabRegiao.activeTab === 2) grid = Metadata.getInstance<Grid>('CONSULTANUTRIENTES-Regiao');
        else if (tabRegiao.activeTab === 3) grid = Metadata.getInstance<Grid>('gridModoPreparoRegiao');
      }

      if (tab === 'subTabReceitaRegiao') {
        if (form.validate()) {
          const padraoQual = form.value.NMPADRAOQUALIDADE.NRPADRAOQUALIDADE;
          const regiao = form.value.NMREGIAO.CDREGIAO;
          const tabs = Metadata.getInstance<Tabs>('subTabReceitaRegiao');
          if (tabs.activeTab === 0) {
            const conditions = [
              {
                name: 'CDPRATO',
                operator: '=',
                value: currentRow.CDPRATO,
              },
              {
                name: 'CDFILAUXPRAT',
                operator: '=',
                value: currentRow.CDFILAUXPRAT,
              },
              {
                name: 'NRPADRAOQUALIDADE',
                operator: '=',
                value: padraoQual,
              },
              {
                name: 'CDREGIAO',
                operator: '=',
                value: regiao,
              },
            ];
            grid.datasource.filter = conditions;
          }
          
          if (!padraoQual && !regiao) {
            if (tabRegiao.activeTab === 0 || tabRegiao.activeTab === 2 || tabRegiao.activeTab === 3
                || tabRegiao.activeTab === 4) {
              const addButton: Button = grid.getChildInstance('addButton');
              grid.datasource.data = [];
              regiao.setValue('');
              addButton.disabled = true;
            } else if (tabRegiao.activeTab === 1) this.dadosReceita.setValuesRecipe();
          } else if (padraoQual && regiao) {
            if (tabRegiao.activeTab === 0 || tabRegiao.activeTab === 2 || tabRegiao.activeTab === 3) {
              grid.datasource.get().then(() => {
                const addButton: Button = grid.getChildInstance('addButton');
                addButton.disabled = false;
                if (tabs.activeTab === 2) {
                  this.consultaNutrientes.filterNutrientesGrid();
                  addButton.disabled = true;
                }
              });
            } else if (tabs.activeTab === 3) this.modoPreparo.setFilters();
            else if (tabs.activeTab === 1) this.dadosReceita.setValuesRecipe();
          }
        } else if (tabRegiao.activeTab === 0 || tabRegiao.activeTab === 2
                  || tabRegiao.activeTab === 3 || tabRegiao.activeTab === 4) {
          const addButton: Button = grid.getChildInstance('addButton');
          grid.datasource.data = [];
          addButton.disabled = true;
        } else if (tabRegiao.activeTab === 1) this.dadosReceita.setValuesRecipe();
      }
    }
  }
  
  public saveRecipeRegion({ component }: IDictionary) {
    const grid: GridEditable = this.utilities.returnGrid(component) as GridEditable;
    const form = Metadata.getInstance<Form>('formRecipeRegion');
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    let currentRow: any;
    if (Object.keys(this.beforeSavePlateForm).length > 0) {
      currentRow = this.beforeSavePlateForm;
    } else currentRow = plateTree.datasource.currentRow;
    const formRegiao = Metadata.getInstance<Form>('FORM_REGIAO');
    
    if (form.validate()) {
      const rows: IDictionary = grid.datasource.data.filter((e: IDictionary) => e.EDITED);
      let ctrlEstoq = true;
      let active = true;
      let validHour = true;

      rows.forEach((e: IDictionary) => {
        // e.NRRECEREGIAO = e.__is_new ? '' : grid.datasource.currentRow.NRRECEREGIAO;
        e.NRRECEREGIAO = e.__is_new ? '' : e.NRRECEREGIAO;
        e.NRPADRAOQUALIDADE = formRegiao.value.NMPADRAOQUALIDADE.NRPADRAOQUALIDADE;
        e.CDPADRAOQUALIDADE = formRegiao.value.NMPADRAOQUALIDADE.CDPADRAOQUALIDADE;
        e.CDREGIAO = formRegiao.value.NMREGIAO.CDREGIAO;
        e.CDPRATO = currentRow.CDPRATO;
        e.CDFILAUXPRAT = currentRow.CDFILAUXPRAT;
        e.SGUNIDADE = e.SGUNIDADE ? e.SGUNIDADE : e.SGUNIDPROD;
        e.CDAPRERECE = e.CDAPRERECE || null;
        // if (e.__is_new) e.CDPRODUTO = e.CDPRODUTOAUX;
        if (e.__is_new && e.IDCNTRESTOQ !== 'S') ctrlEstoq = false;
        if (e.__is_new && e.IDPRODATIV !== 'A') active = false;
        if (e.HRTEMPPREPPRTP && !this.utilities.timeIsValid(e.HRTEMPPREPPRTP)) validHour = false;
        e.HRTEMPPREPPRTP = this.utilities.formatHour(e.HRTEMPPREPPRTP, false);
        e.CDFILCENTPME = this.appController.getCdCentral();
        if (e.originalRow) delete e.originalRow;
        if (e.OLDROW) delete e.OLDROW;
      });

      if (this.receita.saveIsValid(validHour, ctrlEstoq, active)) this.receita.callSave('/saveRecipeRegion', rows, grid);
    } else this.utilities.showAlert('alert', 'pme::verificarCamposObg', 'error');
  }
  
  public setfilterRecipePadraoQualidade() {
    const tab = this.setNameTab;
    if (document.getElementsByName('RECIPE_PADRAOQUALIDADE').length > 0) {
      // const grid: GridEditable = Metadata.getInstance('RECIPE_PADRAOQUALIDADE');
      const form = Metadata.getInstance<Form>('FORM_PADRAOQUALIDADE');
      const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
      let currentRow: any;
      if (Object.keys(this.beforeSavePlateForm).length > 0) {
        currentRow = this.beforeSavePlateForm;
      } else currentRow = plateTree.datasource.currentRow;
      const tabPadraoQuali = Metadata.getInstance<Tabs>('subTabReceitaPadraoQualidade');
      
      let grid: any;
      if (tab === 'subTabReceitaPadraoQualidade') {
        if (tabPadraoQuali.activeTab === 0) grid = Metadata.getInstance<GridEditable>('RECIPE_PADRAOQUALIDADE');
        else if (tabPadraoQuali.activeTab === 2) grid = Metadata.getInstance<Grid>('CONSULTANUTRIENTES-PadrQual');
        else if (tabPadraoQuali.activeTab === 3) grid = Metadata.getInstance<Grid>('gridModoPreparoPadraoQualidade');
      }
      
      if (tab === 'subTabReceitaPadraoQualidade') {
        if (form.validate()) {
          const padraoQual = form.value.NMPADRAOQUALIDADE.NRPADRAOQUALIDADE;
          const tabs = Metadata.getInstance<Tabs>('subTabReceitaPadraoQualidade');
          if (tabs.activeTab === 0) {
            const conditions = [
              {
                name: 'CDPRATO',
                operator: '=',
                value: currentRow.CDPRATO,
              },
              {
                name: 'CDFILAUXPRAT',
                operator: '=',
                value: currentRow.CDFILAUXPRAT,
              },
              {
                name: 'NRPADRAOQUALIDADE',
                operator: '=',
                value: padraoQual,
              },
            ];
            grid.datasource.filter = conditions;
          }
          
          if (!padraoQual) {
            if (tabPadraoQuali.activeTab === 0 || tabPadraoQuali.activeTab === 2
                || tabPadraoQuali.activeTab === 3 || tabPadraoQuali.activeTab === 4) {
              const addButton: Button = grid.getChildInstance('addButton');
              grid.datasource.data = [];
              addButton.disabled = true;
            } else if (tabPadraoQuali.activeTab === 1) this.dadosReceita.setValuesRecipe();
          } else if (padraoQual) {
            if (tabPadraoQuali.activeTab === 0 || tabPadraoQuali.activeTab === 2
                || tabPadraoQuali.activeTab === 3 || tabPadraoQuali.activeTab === 4) {
              grid.datasource.get().then(() => {
                const addButton: Button = grid.getChildInstance('addButton');
                addButton.disabled = false;
                if (tabs.activeTab === 2) {
                  this.consultaNutrientes.filterNutrientesGrid();
                  addButton.disabled = true;
                }
              });
            } else if (tabs.activeTab === 3) this.modoPreparo.setFilters();
            else if (tabs.activeTab === 1) this.dadosReceita.setValuesRecipe();
          }
        } else if (tabPadraoQuali.activeTab === 0 || tabPadraoQuali.activeTab === 2
                  || tabPadraoQuali.activeTab === 3 || tabPadraoQuali.activeTab === 4) {
          const addButton: Button = grid.getChildInstance('addButton');
          grid.datasource.data = [];
          addButton.disabled = true;
        } else if (tabPadraoQuali.activeTab === 1) this.dadosReceita.setValuesRecipe();
      }
    }
  }
  
  public saveRecipePadraoQualidade({ component }: IDictionary) {
    // const grid = Metadata.getInstance<GridEditable>('RECIPE_PADRAOQUALIDADE');
    const grid: GridEditable = this.utilities.returnGrid(component) as GridEditable;
    const form = Metadata.getInstance<Form>('formRecipePadraoQualidade');
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    let currentRow: any;
    if (Object.keys(this.beforeSavePlateForm).length > 0) {
      currentRow = this.beforeSavePlateForm;
    } else currentRow = plateTree.datasource.currentRow;
    const formPadQuali = Metadata.getInstance<Form>('FORM_PADRAOQUALIDADE');
    
    if (form.validate()) {
      const rows: IDictionary = grid.datasource.data.filter((e: IDictionary) => e.EDITED);
      let ctrlEstoq = true;
      let active = true;
      const validHour = true;

      rows.forEach((e: IDictionary) => {
        // e.NRRECEPADQUALI = e.__is_new ? '' : grid.datasource.currentRow.NRRECEPADQUALI;
        e.NRRECEPADQUALI = e.__is_new ? '' : e.NRRECEPADQUALI;
        e.NRPADRAOQUALIDADE = formPadQuali.value.NMPADRAOQUALIDADE.NRPADRAOQUALIDADE;
        e.CDPADRAOQUALIDADE = formPadQuali.value.NMPADRAOQUALIDADE.CDPADRAOQUALIDADE;
        e.CDPRATO = currentRow.CDPRATO;
        e.CDFILAUXPRAT = currentRow.CDFILAUXPRAT;
        e.SGUNIDADE = e.SGUNIDADE ? e.SGUNIDADE : e.SGUNIDPROD;
        e.CDAPRERECE = e.CDAPRERECE || null;
        // if (e.__is_new) e.CDPRODUTO = e.CDPRODUTOAUX;
        if (e.__is_new && e.IDCNTRESTOQ !== 'S') ctrlEstoq = false;
        if (e.__is_new && e.IDPRODATIV !== 'A') active = false;
        e.CDFILCENTPME = this.appController.getCdCentral();
        if (e.originalRow) delete e.originalRow;
        if (e.OLDROW) delete e.OLDROW;
      });
    
      if (this.receita.saveIsValid(validHour, ctrlEstoq, active)) {
        this.receita.callSave('/saveRecipePadraoQualidade', rows, grid);
      }
    } else this.utilities.showAlert('alert', 'pme::verificarCamposObg', 'error');
  }
  
  // Modal Importação
  
  // public async createImportModal() {
  //   this.modalImport = await ModalService.createFromJson('planejamento/prato/modals/importacaoReceita', true);
  // }
    
  // public showModalImport({ component }: IDictionary) {
  //   this.modalImport.show();
  //   const name = component.name;
  //   if (name.includes('PADRAO') > 0) this.recipeDest = 'PADRAO';
  //   else if (name.includes('TIPOCARD') > 0) this.recipeDest = 'TIPOCARD';
  //   else if (name.includes('LOCAL') > 0) this.recipeDest = 'LOCAL';
  //   else this.recipeDest = 'SERVICO';

  //   const gridDest = this.utilities.returnGrid(component) as GridEditable;
  //   this.prodDest = gridDest.datasource.data;
  // }
  
  /* public closeModalImport() {
    this.modalImport.hide();
  } */
  
  // Dados da Receita
  
  /* public get visibleField() {
    const nameTab = this.setNameTab;
    if (nameTab === 'subTabReceitaRegiao' || nameTab === 'subTabReceitaPadraoQualidade') return false;
    return true;
  } */
  
  public setNameTabRecipe({ component }: IEventParam<Tabs>) {
    if (component.name === 'tabPratos' && component) {
      if (component.activeTab === 2) this.setNameTab = 'subTabReceitaPadrao';
      else if (component.activeTab === 3) this.setNameTab = 'subTabReceitaTipoCard';
      else if (component.activeTab === 4) this.setNameTab = 'subTabReceitaLocal';
      else if (component.activeTab === 5) this.setNameTab = 'subTabReceitaServico';
      else if (component.activeTab === 6) this.setNameTab = 'subTabReceitaPadraoQualidade';
      else if (component.activeTab === 7) this.setNameTab = 'subTabReceitaRegiao';
    } else this.setNameTab = component.name;
    
    this.dadosReceita.setNameTabRecipe();
    this.setCalculateNDPCAL();
  }
  
  public setCalculateNDPCAL() {
    const tab = this.setNameTab;
    if (tab === 'subTabReceitaPadrao') {
      if (document.getElementsByName('subTabReceitaPadrao').length > 0) {
        const subTabReceitaPadrao = Metadata.getInstance<Tabs>('subTabReceitaPadrao');
        if (subTabReceitaPadrao.activeTab === 0) this.setfilterRecipeStandard();
        else if (subTabReceitaPadrao.activeTab === 1) this.dadosReceita.setValuesRecipe();
        else if (subTabReceitaPadrao.activeTab === 2) this.consultaCustos.filterPlatesGrid();
        else if (subTabReceitaPadrao.activeTab === 3) this.consultaNutrientes.calcularNDPCAL();
        else if (subTabReceitaPadrao.activeTab === 4) this.modoPreparo.setFilters();
        else if (subTabReceitaPadrao.activeTab === 5) this.setImageSrc();
      }
    } else if (tab === 'subTabReceitaTipoCard') {
      if (document.getElementsByName('subTabReceitaTipoCard').length > 0) {
        const subTabReceitaTipoCard = Metadata.getInstance<Tabs>('subTabReceitaTipoCard');
        if (subTabReceitaTipoCard.activeTab === 0) this.setfilterRecipeTpCard();
        else if (subTabReceitaTipoCard.activeTab === 1) this.dadosReceita.setValuesRecipe();
        else if (subTabReceitaTipoCard.activeTab === 2) this.consultaCustos.filterPlatesGrid();
        else if (subTabReceitaTipoCard.activeTab === 3) this.consultaNutrientes.calcularNDPCAL();
        else if (subTabReceitaTipoCard.activeTab === 4) this.modoPreparo.setFilters();
        else if (subTabReceitaTipoCard.activeTab === 5) this.setImageSrc();
      }
    } else if (tab === 'subTabReceitaLocal') {
      if (document.getElementsByName('subTabReceitaLocal').length > 0) {
        const subTabReceitaLocal = Metadata.getInstance<Tabs>('subTabReceitaLocal');
        if (subTabReceitaLocal.activeTab === 0) this.setFilterRecipeLocal();
        else if (subTabReceitaLocal.activeTab === 1) this.dadosReceita.setValuesRecipe();
        else if (subTabReceitaLocal.activeTab === 2) this.consultaCustos.filterPlatesGrid();
        else if (subTabReceitaLocal.activeTab === 3) this.consultaNutrientes.calcularNDPCAL();
        else if (subTabReceitaLocal.activeTab === 4) this.modoPreparo.setFilters();
        else if (subTabReceitaLocal.activeTab === 5) this.setImageSrc();
      }
    } else if (tab === 'subTabReceitaServico') {
      if (document.getElementsByName('subTabReceitaServico').length > 0) {
        const subTabReceitaServico = Metadata.getInstance<Tabs>('subTabReceitaServico');
        if (subTabReceitaServico.activeTab === 0) this.setFilterRecipeService();
        if (subTabReceitaServico.activeTab === 1) this.dadosReceita.setValuesRecipe();
        else if (subTabReceitaServico.activeTab === 2) this.consultaCustos.filterPlatesGrid();
        else if (subTabReceitaServico.activeTab === 3) this.consultaNutrientes.calcularNDPCAL();
        else if (subTabReceitaServico.activeTab === 4) this.modoPreparo.setFilters();
        else if (subTabReceitaServico.activeTab === 5) this.setImageSrc();
      }
    } else if (tab === 'subTabReceitaTipoCard') {
      if (document.getElementsByName('subTabReceitaTipoCard').length > 0) {
        const subTabReceitaTipoCard = Metadata.getInstance<Tabs>('subTabReceitaTipoCard');
        if (subTabReceitaTipoCard.activeTab === 0) this.setfilterRecipeTpCard();
        if (subTabReceitaTipoCard.activeTab === 1) this.dadosReceita.setValuesRecipe();
        else if (subTabReceitaTipoCard.activeTab === 2) this.consultaCustos.filterPlatesGrid();
        else if (subTabReceitaTipoCard.activeTab === 3) this.consultaNutrientes.calcularNDPCAL();
        else if (subTabReceitaTipoCard.activeTab === 4) this.modoPreparo.setFilters();
        else if (subTabReceitaTipoCard.activeTab === 5) this.setImageSrc();
      }
    } else if (tab === 'subTabReceitaServico') {
      if (document.getElementsByName('subTabReceitaServico').length > 0) {
        const subTabReceitaServico = Metadata.getInstance<Tabs>('subTabReceitaServico');
        if (subTabReceitaServico.activeTab === 1) this.dadosReceita.setValuesRecipe();
        else if (subTabReceitaServico.activeTab === 2) this.consultaCustos.filterPlatesGrid();
        else if (subTabReceitaServico.activeTab === 3) this.consultaNutrientes.calcularNDPCAL();
        else if (subTabReceitaServico.activeTab === 4) this.modoPreparo.setFilters();
        else if (subTabReceitaServico.activeTab === 5) this.setImageSrc();
      }
    } else if (tab === 'subTabReceitaPadraoQualidade') {
      if (document.getElementsByName('subTabReceitaPadraoQualidade').length > 0) {
        const subTabReceitaPadraoQualidade = Metadata.getInstance<Tabs>('subTabReceitaPadraoQualidade');
        if (subTabReceitaPadraoQualidade.activeTab === 0) this.setfilterRecipePadraoQualidade();
        else if (subTabReceitaPadraoQualidade.activeTab === 1) this.dadosReceita.setValuesRecipe();
        else if (subTabReceitaPadraoQualidade.activeTab === 2) this.consultaCustos.filterPlatesGrid();
        else if (subTabReceitaPadraoQualidade.activeTab === 3) this.modoPreparo.setFilters();
        // else if (subTabReceitaPadraoQualidade.activeTab === 5) this.setImageSrc();
      }
    } else if (tab === 'subTabReceitaRegiao') {
      if (document.getElementsByName('subTabReceitaRegiao').length > 0) {
        const subTabReceitaRegiao = Metadata.getInstance<Tabs>('subTabReceitaRegiao');
        if (subTabReceitaRegiao.activeTab === 0) this.setfilterRecipeRegion();
        else if (subTabReceitaRegiao.activeTab === 1) this.dadosReceita.setValuesRecipe();
        else if (subTabReceitaRegiao.activeTab === 2) this.consultaCustos.filterPlatesGrid();
        else if (subTabReceitaRegiao.activeTab === 3) this.modoPreparo.setFilters();
        // else if (subTabReceitaRegiao.activeTab === 5) this.setImageSrc();
      }
    }
  }
  
  public validOperator() {
    const padrao: any = 'P';
    const row = {
      COLUMN_NAME: 'CDGROPERREPA',
      ALIAS_NAME: 'ALTRECEPADRAO',
    };
    if (this.modalPlates || this.showPratoNvlCompleto) {
      const component: Tabs = Metadata.getInstance('tabPratos');
      if ((component.activeTab === 2 && this.cdGroupOperRepa === '') || (padrao === 'P' && this.cdGroupOperRepa === '')) {
        Http.post('/prato/returnParamsAddPlate', { requestType: 'Row', row }).then((callback) => {
          const result = callback.data.dataset.permission.result;
          if (result === 'NOPERMISSION') this.operatorValid = false;
          else this.operatorValid = true;
          this.cdGroupOperRepa = callback.data.dataset.paramgeral[0].CDGROPERREPA;
        });
      }
      
      // if (component.activeTab === 1) this.setfilterEmbalagem();
      this.setNameTabRecipe({ component });
    } else if (padrao === 'P' && this.cdGroupOperRepa === '') {
      Http.post('/prato/returnParamsAddPlate', { requestType: 'Row', row }).then((callback) => {
        const result = callback.data.dataset.permission.result;
        if (result === 'NOPERMISSION') this.operatorValid = false;
        else this.operatorValid = true;
        this.cdGroupOperRepa = callback.data.dataset.paramgeral[0].CDGROPERREPA;
      });
    }
    this.createModalGroupOperador();
  }
  
  public searchOpLogado({ component }: Button) {
    const tab = this.setNameTab;
    
    let padrao: any;
    if (component === 'ZdSelect') padrao = 'P';
    
    if (tab === 'subTabReceitaPadrao' || padrao === 'P') {
      if (this.operatorValid === false) {
        const row = {
          CDOPERADOR: localStorage.getItem('CDOPERADOR'),
        };
        Http.post('/prato/operGrup', { requestType: 'Row', row }).then((callback) => {
          const resultCodGrupo = callback.data.dataset.result[0]?.CDGRUPOPER;
          if (resultCodGrupo !== this.cdGroupOperRepa) {
            this.utilities.showAlert('Alert', 'pme::modificacaoRecPadrao', 'warning');
            this.openModalGroupOperador(component);
          }
        });
      }
    } else if (tab === 'subTabReceitaPadrao' && this.operatorValid === true) this.receita.addRow({ component });
  }
  
  public addRowRecipePadrao({ component }: IEventParam<Button>) {
    const buttonAdd = Metadata.getInstance<Button>('addButtonPad');
    if (this.operatorValid !== false) this.receita.addRow({ component: buttonAdd });
    else {
      this.utilities.showAlert('Alert', 'pme::modificacaoRecPadrao', 'warning');
      this.openModalGroupOperador(component);
    }
  }

  private async createModalGroupOperador() {
    if (!this.modalGroupOperador) {
      this.modalGroupOperador = await ModalService.createFromJson('planejamento/prato/modals/formGroupOperador', true);
    }
  }

  public closeModalGroupOperador() {
    this.modalGroupOperador.hide();
  }
  
  public openModalGroupOperador(component?: any) {
    if (component) this.nameComponentOperador = component.name;
    if (!this.modalGroupOperador) {
      this.createModalGroupOperador().then(() => {
        this.modalGroupOperador.show();
      });
    } else {
      this.modalGroupOperador.show();
    }
  }
  
  // validar
  public saveOperator() {
    const tab = this.setNameTab;
    const form = Metadata.getInstance<Form>('formGroupOper');
    const row = form.value;
    row.EMAIL = row.DSEMAILOPER;
    row.SENHA = row.CDSENHAOPERWEB;
     
    if (form.validate()) {
      LoadingService.show(' ');
      Http.post('/prato/autenticar', { requestType: 'Row', row }).then((permission) => {
        if (permission.data.dataset.permission.isValid !== false) {
          Http.post('/prato/saveOperator', { requestType: 'Row', row }).then((result) => {
            const msg = result.data.dataset.result.message;
            if (msg === 'INVALID_PASSWORD' || msg === 'operadorNaoCadastrado') {
              this.utilities.showAlert('Alert', 'pme::ERROR_SENHAUSUARIONEGADO', 'error');
              this.operatorValid = false;
            } else if (msg === null) {
              this.operatorValid = true;
              this.closeModalGroupOperador();
              if (tab === 'subTabReceitaPadrao') {
                const subTabReceitaPadrao = Metadata.getInstance<Tabs>('subTabReceitaPadrao');
                if (subTabReceitaPadrao.activeTab === 1) {
                  const button: Button = Metadata.getInstance('saveButtonRecipePadrao');
                  this.dadosReceita.salvaDadosRecipePlate(button);
                }
              }
            } else this.operatorValid = false;
          }).catch((erro: string) => {
            this.utilities.showAlert('alert', `pme::${erro}`, 'error');
          });
        } else this.utilities.showAlert('alert', 'pme::unauthorizedOperator', 'error');
      }).catch((erro: string) => {
        this.utilities.showAlert('alert', `pme::${erro}`, 'error');
      }).finally(() => {
        LoadingService.hide();
      });
    }
  }
  
  /* public setFilterAgregAgrup({ component }: IEventParam<Select>) {
    const agrupUnid = Metadata.getInstance<Select>('GRUPFILI');
    
    const conditions = [
      {
        name: 'P_CDGRUPFILI',
        operator: '=',
        value: agrupUnid.value?.CDGRUPFILI ? agrupUnid.value.CDGRUPFILI : 'T',
      },
    ];
    
    component.datasource.filter = conditions;
    component.datasource.get();
  } */
  
  /* public setFilterServAgrupUnid({ component }: IEventParam<Select>) {
    const unidade = Metadata.getInstance<Select>('UNIDADE');
    const unidadeValue = (unidade.value.length !== 0) ? unidade.value.join('_') : 'T';
    
    const agrupUnid = Metadata.getInstance<Select>('GRUPFILI');
    const agrupUnidValue = agrupUnid.value ? agrupUnid.value.CDGRUPFILI : 'T';
    
    const grupserv = Metadata.getInstance<Select>('GRUPOSERVICO');
    const grupServValue = grupserv.value ? grupserv.value : 'T';
    
    const filter = [
      {
        name: 'CDGRUPFILI',
        operator: '=',
        value: agrupUnidValue,
      },
      {
        name: 'CDFILIAL',
        operator: '=',
        value: unidadeValue,
      },
      {
        name: 'CDGRUPSERV',
        operator: '=',
        value: grupServValue,
      },
      {
        name: 'IDTIPOSERV',
        operator: '=',
        value: this.project === 'PAE' ? '' : 'N',
      },
    ];
    
    component.datasource.filter = filter;
    component.datasource.get();
  } */
  
  /* public controllPratoIni() {
    const pratoFinal = Metadata.getInstance<Select>('PRATO_FINAL');
    if (pratoFinal.value !== null) pratoFinal.setValue(null);
  } */
  
  /* public verifyPratIni({ component }: IEventParam<Select>) {
    const form = Metadata.getInstance<Form>('formFilter');
    if (component.value !== null) {
      if (this.utilities.returnPrat(form.getChildInstance<Select>('PRATO_INICIAL').value, component.value)) {
        this.utilities.showAlert('Alert', 'pme::pratoIniMaior', 'error');
        component.setValue(null);
      }
    }
  } */
  
  public getSafColor({ row }: IDictionary) {
    let decColor = 0;
    const nrcorsafra = this.utilities.hexToRgbInline(this.nrcorsafra).split('.', 3);
    const nrcorinicsaf = this.utilities.hexToRgbInline(this.nrcorinicsaf).split('.', 3);
    const nrcorentrsaf = this.utilities.hexToRgbInline(this.nrcorentrsaf).split('.', 3);
    
    if (row.IDINTESAFR > 0) {
      if (row.IDINTESAFR === '1') {
        decColor = this.utilities.RGBToTColor(nrcorsafra[0], nrcorsafra[1], nrcorsafra[2]);
        row.SAFRA = I18n.translate('pme::safra');
      }
      if (row.IDINTESAFR === '2') {
        decColor = this.utilities.RGBToTColor(nrcorinicsaf[0], nrcorinicsaf[1], nrcorinicsaf[2]);
        row.SAFRA = I18n.translate('pme::inicioFimSafra');
      }
      if (row.IDINTESAFR === '3') {
        decColor = this.utilities.RGBToTColor(nrcorentrsaf[0], nrcorentrsaf[1], nrcorentrsaf[2]);
        row.SAFRA = I18n.translate('pme::entreSafra');
      }
    } else row.IDINTESAFR = '';
    
    const color = this.utilities.TColorToHex(decColor.toString());
    
    return color;
  }
  
  // verificacao op logados dados receita padrao
  
  public salvaDadosRecipePlate() {
    const component: Button = Metadata.getInstance('saveButtonRecipePadrao');
    if (this.operatorValid !== false) {
      this.dadosReceita.salvaDadosRecipePlate({ component });
    } else {
      this.utilities.showAlert('Alert', 'pme::modificacaoRecPadrao', 'warning');
      this.openModalGroupOperador(component);
    }
  }
  
  // verificação op logado receita padrao
  public deleteRecipeStandardPlate({ component }: IEventParam<Button>) {
    const buttonDelete = Metadata.getInstance<Button>('delButtonPad');
    if (this.operatorValid !== false) {
      this.receita.deleteRecipeStandard({ component: buttonDelete });
    } else {
      this.utilities.showAlert('Alert', 'pme::modificacaoRecPadrao', 'warning');
      this.openModalGroupOperador(component);
    }
  }
  
  public onInlineEditRecipeStandart({ component }: IEventParam<Button>) {
    const grid: Grid = Metadata.getInstance('RECIPE_STANDARD');

    if (this.operatorValid !== false) {
      this.gridEditController.onInlineEdit({ component: grid });
    } else {
      this.utilities.showAlert('Alert', 'pme::modificacaoRecPadrao', 'warning');
      this.openModalGroupOperador(component);
      // this.gridEditController.reload({ component: grid });
      // toolbarSlot.forEach((e: IComponentRender) => {
      //   if (e.name === 'cancelButton') e.disabled = !e.disabled;
      //   if (e.name === 'saveButton') e.disabled = !e.disabled;
      // });
    }
  }
  
  // modal emissao receitas
  
  private async createModalEmissaoReceitas() {
    this.modalEmissaoReceitas = await ModalService.createFromJson(
      'planejamento/prato/modals/pla01303_emissao_receitas', true,
    );
  }

  public closeModalEmissaoReceitas() {
    this.modalEmissaoReceitas.hide();
    this.modalEmissaoReceitas.destroy();
    this.modalEmissaoReceitas = this.utilities.modalEmpty;
  }
  
  public openModalEmissaoReceitas() {
    if (!this.modalEmissaoReceitas) {
      this.createModalEmissaoReceitas().then(() => {
        this.modalEmissaoReceitas.show();
      });
    } else {
      this.modalEmissaoReceitas.show();
    }
  }
  
  public async setImageSrc() {
    const tab = this.setNameTab;
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    const currentRow = plateTree.datasource.currentRow;
    const row = {
      CDPRATO: currentRow.CDPRATO,
      CDFILAUXPRAT: currentRow.CDFILAUXPRAT ? currentRow.CDFILAUXPRAT : 'P',
      IDRECEITA: '',
      CDFILIAL: null,
      CDSERVFILI: null,
      CDFILCENTPME: null,
      CDTIPOCARD: null,
    };
    
    let name;
    if (tab === 'subTabReceitaPadrao') {
      row.IDRECEITA = 'P';
      row.CDFILIAL = null;
      row.CDSERVFILI = null;
      name = 'Padrao';
    } else if (tab === 'subTabReceitaTipoCard') {
      row.IDRECEITA = 'T';
      const form = Metadata.getInstance<Form>('FORM_TIPOCARD');
      const tipoCard = form.value.TIPOCARD?.CDTIPOCARD;
      row.CDFILCENTPME = this.appController.getCdCentral();
      row.CDTIPOCARD = tipoCard || null;
      name = 'TipoCard';
    } else if (tab === 'subTabReceitaLocal') {
      row.IDRECEITA = 'F';
      const form = Metadata.getInstance<Form>('FORM_LOCAL');
      const unidade = form.value.BRANCH_LOCAL?.CDFILIAL;
      row.CDFILIAL = unidade || null;
      row.CDSERVFILI = null;
      name = 'Local';
    } else if (tab === 'subTabReceitaServico') {
      row.IDRECEITA = 'S';
      const form = Metadata.getInstance<Form>('FORM_SERVICE');
      const unidade = form.value.BRANCH_SERVICE?.CDFILIAL;
      const servico = form.value.SERVICE?.CDSERVFILI;
      row.CDFILIAL = unidade || null;
      row.CDSERVFILI = servico || null;
      name = 'Servico';
    }
    
    if (document.getElementsByName(`plateImage-${name}`).length > 0) {
      const image = Metadata.getInstance<Image>(`plateImage-${name}`);
      const imageInput = Metadata.getInstance<FileInput>(`imageInput-${name}`);
      if (imageInput.value) {
        image.src = await this.fileToBase64(imageInput.value) as string;
      } else {
        LoadingService.show(' ');
        Http.post('/prato/getImage', { requestType: 'Row', row }).then((response) => {
          if (response.data.dataset.image.FGFOTOPRATOURL) {
            image.src = response.data.dataset.image.FGFOTOMOBILE;
            this.nrFotoPratoBlob = response.data.dataset.image.NRFOTOPRATOBLOB;
          } else if (response.data.dataset.image.HASFGFOTOPRATO === 'S') {
            const url = Config.endPoint + Config.env.baseUrl;
            let src = `${url}prato/getImageBlob?CDPRATO=${row.CDPRATO}&CDFILAUXPRAT=${row.CDFILAUXPRAT}`;
            src = `${src}&IDRECEITA=${row.IDRECEITA}&CDFILIAL=${row.CDFILIAL}&CDSERVFILI=${row.CDSERVFILI}`;
            // &CDFILCENTPME=${row.CDFILCENTPME}&CDTIPOCARD=${row.CDTIPOCARD}`;
            this.nrFotoPratoBlob = response.data.dataset.image.NRFOTOPRATOBLOB;
            image.src = src;
          } else {
            this.nrFotoPratoBlob = '';
            image.src = '/assets/img/image-not-found.svg';
          }
          this.disabledAdd();
        }).finally(() => {
          LoadingService.hide();
        });
      }
    }
  }
  
  public async saveImage() {
    const tab = this.setNameTab;
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    const currentRow = plateTree.datasource.currentRow;
    const row = {
      CDPRATO: currentRow.CDPRATO,
      CDFILAUXPRAT: currentRow.CDFILAUXPRAT ? currentRow.CDFILAUXPRAT : 'P',
      IDRECEITA: '',
      CDFILIAL: null,
      CDSERVFILI: null,
      CDFILCENTPME: null,
      CDTIPOCARD: null,
      IMAGE_UPLOAD: Array<IDictionary>(),
    };
    let name;
    if (tab === 'subTabReceitaPadrao') {
      row.IDRECEITA = 'P';
      row.CDFILIAL = null;
      row.CDSERVFILI = null;
      name = 'Padrao';
    } else if (tab === 'subTabReceitaTipoCard') {
      row.IDRECEITA = 'T';
      const form = Metadata.getInstance<Form>('FORM_TIPOCARD');
      const tipoCard = form.value.TIPOCARD?.CDTIPOCARD;
      row.CDFILCENTPME = this.appController.getCdCentral();
      row.CDTIPOCARD = tipoCard || null;
      name = 'TipoCard';
    } else if (tab === 'subTabReceitaLocal') {
      row.IDRECEITA = 'F';
      const form = Metadata.getInstance<Form>('FORM_LOCAL');
      const unidade = form.value.BRANCH_LOCAL?.CDFILIAL;
      row.CDFILIAL = unidade || null;
      row.CDSERVFILI = null;
      name = 'Local';
    } else if (tab === 'subTabReceitaServico') {
      row.IDRECEITA = 'S';
      const form = Metadata.getInstance<Form>('FORM_SERVICE');
      const unidade = form.value.BRANCH_SERVICE?.CDFILIAL;
      const servico = form.value.SERVICE?.CDSERVFILI;
      row.CDFILIAL = unidade || null;
      row.CDSERVFILI = servico || null;
      name = 'Servico';
    }
    const imageInput = Metadata.getInstance<FileInput>(`imageInput-${name}`);
    if (imageInput.acceptCheck(imageInput.value) && imageInput.validate()) {
      if (Config.env.nodeEnv !== 'production' && imageInput.value?.size >= 500000) {
        this.utilities.showAlert('Alert', 'pme::arquivoGrande', 'error');
      } else {
        const fileSent = imageInput.value;
        const fileContent = {
          name: fileSent.name,
          lastModified: fileSent.lastModified,
          lastModifiedDate: fileSent.lastModifiedDate,
          webkitRelativePath: fileSent.webkitRelativePath,
          size: fileSent.size,
          type: fileSent.type,
          b64File: await this.fileToBase64(fileSent),
        };
        row.IMAGE_UPLOAD[0] = fileContent;
        LoadingService.show(' ');
        Http.post('/prato/saveImage', { requestType: 'Row', row, IMAGE_UPLOAD: [fileContent] }).then(() => {
          this.utilities.showAlert('alert', 'pme::salvoComSucesso', 'success');
          this.setImageSrc();
          this.cancelEditImage();
        }).catch((error: string) => {
          this.utilities.showAlert('alert', `${error}`, 'error');
        }).finally(() => {
          LoadingService.hide();
        });
      }
    } else this.utilities.showAlert('Alert', 'pme::imagemExtensaoErrada', 'error');
  }
  
  public async editImage() {
    const tab = this.setNameTab;
    let name;
    if (tab === 'subTabReceitaPadrao') {
      name = 'Padrao';
    } else if (tab === 'subTabReceitaTipoCard') {
      name = 'TipoCard';
    } else if (tab === 'subTabReceitaLocal') {
      name = 'Local';
    } else if (tab === 'subTabReceitaServico') {
      name = 'Servico';
    }
    const addButton = Metadata.getInstance<Button>(`addButtonImagem-${name}`);
    const excluiBtn = Metadata.getInstance<Button>(`excluiImagem-${name}`);
    const reloadBtn = Metadata.getInstance<Button>(`reloadButton-${name}`);
    const cancelBtnImagem = Metadata.getInstance<Button>(`cancelButtonImagem-${name}`);
    const saveBtnImagem = Metadata.getInstance<Button>(`saveButtonImagem-${name}`);
    const imageInput = Metadata.getInstance<FileInput>(`imageInput-${name}`);
    const image = Metadata.getInstance<Image>(`plateImage-${name}`);
    if (imageInput.value === null || imageInput.value === [] || imageInput.value === undefined) {
      addButton.disabled = false;
      excluiBtn.disabled = false;
      reloadBtn.disabled = false;
      cancelBtnImagem.disabled = true;
      saveBtnImagem.disabled = true;
      // this.disabledAdd();
    } else {
      addButton.disabled = true;
      excluiBtn.disabled = true;
      reloadBtn.disabled = true;
      cancelBtnImagem.disabled = false;
      saveBtnImagem.disabled = false;
      // this.disabledAdd();
      image.src = await this.fileToBase64(imageInput.value) as string;
    }
    // this.disabledAdd();
    this.setImageSrc();
  }
  
  public cancelEditImage() {
    const tab = this.setNameTab;
    let name;
    if (tab === 'subTabReceitaPadrao') {
      name = 'Padrao';
    } else if (tab === 'subTabReceitaTipoCard') {
      name = 'TipoCard';
    } else if (tab === 'subTabReceitaLocal') {
      name = 'Local';
    } else if (tab === 'subTabReceitaServico') {
      name = 'Servico';
    }
    const imageInput = Metadata.getInstance<FileInput>(`imageInput-${name}`);
    imageInput.value = [];
    
    // const addButton = Metadata.getInstance<Button>(`addButtonImagem-${name}`);
    const excluiBtn = Metadata.getInstance<Button>(`excluiImagem-${name}`);
    const reloadBtn = Metadata.getInstance<Button>(`reloadButton-${name}`);
    const cancelBtnImagem = Metadata.getInstance<Button>(`cancelButtonImagem-${name}`);
    const saveBtnImagem = Metadata.getInstance<Button>(`saveButtonImagem-${name}`);
    
    // this.disabledAdd();
    // addButton.disabled = false;
    excluiBtn.disabled = false;
    reloadBtn.disabled = false;
    cancelBtnImagem.disabled = true;
    saveBtnImagem.disabled = true;
    this.setImageSrc();
  }
  
  private fileToBase64(file: File) {
    return new Promise((resolve, reject) => {
      const reader = new FileReader();
      reader.readAsDataURL(file);
      reader.onload = () => resolve(reader.result?.toString() || '');
      reader.onerror = (error) => reject(error);
    });
  }
  
  public showDeleteImage() {
    DialogService.show({
      name: 'delete',
      type: 'warning',
      title: 'pme::atencao',
      text: 'pme::desejaExcluir',
      buttons: [
        {
          name: 'yesDelete',
          component: 'ZdButton',
          label: 'pme::sim',
          events: { click: () => this.deleteImage() },
          outline: true,
        },
        {
          name: 'noDelete',
          component: 'ZdButton',
          label: 'pme::nao',
          events: { click: () => DialogService.hide() },
        },
        {
          name: 'progressLine',
          component: 'ZdProgress',
          label: 'Progress',
          indeterminate: true,
          cssClass: 'loading-progress-line',
        },
      ],
    });
  }
  
  public deleteImage() {
    DialogService.hide();
    const tab = this.setNameTab;
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    const currentRow = plateTree.datasource.currentRow;
    const row = {
      CDPRATO: currentRow.CDPRATO,
      CDFILAUXPRAT: currentRow.CDFILAUXPRAT ? currentRow.CDFILAUXPRAT : 'P',
      IDRECEITA: '',
      CDFILIAL: null,
      CDSERVFILI: null,
      CDFILCENTPME: null,
      CDTIPOCARD: null,
      NRFOTOPRATOBLOB: this.nrFotoPratoBlob,
    };
    if (tab === 'subTabReceitaPadrao') {
      row.IDRECEITA = 'P';
      row.CDFILIAL = null;
      row.CDSERVFILI = null;
    } else if (tab === 'subTabReceitaTipoCard') {
      row.IDRECEITA = 'T';
      const form = Metadata.getInstance<Form>('FORM_TIPOCARD');
      const tipoCard = form.value.TIPOCARD?.CDTIPOCARD;
      row.CDFILCENTPME = this.appController.getCdCentral();
      row.CDTIPOCARD = tipoCard || null;
    } else if (tab === 'subTabReceitaLocal') {
      row.IDRECEITA = 'F';
      const form = Metadata.getInstance<Form>('FORM_LOCAL');
      const unidade = form.value.BRANCH_LOCAL?.CDFILIAL;
      row.CDFILIAL = unidade || null;
      row.CDSERVFILI = null;
    } else if (tab === 'subTabReceitaServico') {
      row.IDRECEITA = 'S';
      const form = Metadata.getInstance<Form>('FORM_SERVICE');
      const unidade = form.value.BRANCH_SERVICE?.CDFILIAL;
      const servico = form.value.SERVICE?.CDSERVFILI;
      row.CDFILIAL = unidade || null;
      row.CDSERVFILI = servico || null;
    }
    LoadingService.show(' ');
    Http.post('/prato/deleteImage', { requestType: 'Row', row }).then(() => {
      this.utilities.showAlert('alert', 'pme::excluidoComSucesso', 'success');
      this.setImageSrc();
      this.cancelEditImage();
    }).catch((error: string) => {
      this.utilities.showAlert('alert', `${error}`, 'error');
    }).finally(() => {
      LoadingService.hide();
    });
  }
  
  public disabledAdd() {
    let result;
    const tab = this.setNameTab;
    let name;
    if (tab === 'subTabReceitaPadrao') {
      name = 'Padrao';
    } else if (tab === 'subTabReceitaTipoCard') {
      name = 'TipoCard';
    } else if (tab === 'subTabReceitaLocal') {
      name = 'Local';
    } else if (tab === 'subTabReceitaServico') {
      name = 'Servico';
    }
    if (document.getElementsByName(`plateImage-${name}`).length > 0) {
      const image = Metadata.getInstance<Image>(`plateImage-${name}`);
      const imageInput = Metadata.getInstance<FileInput>(`imageInput-${name}`);
      if (image.src === '/assets/img/image-not-found.svg'
        && (imageInput.value === null || imageInput.value === [] || imageInput.value === undefined)) {
        result = false;
      } else result = true;
    } else result = false;
    const addButton = Metadata.getInstance<Button>(`addButtonImagem-${name}`);
    addButton.disabled = result;
    const excluiBtn = Metadata.getInstance<Button>(`excluiImagem-${name}`);
    excluiBtn.disabled = !result;
    // return result;
  }
  
  public addImage() {
    let name;
    const tab = this.setNameTab;
    if (tab === 'subTabReceitaPadrao') {
      name = 'Padrao';
    } else if (tab === 'subTabReceitaTipoCard') {
      name = 'TipoCard';
    } else if (tab === 'subTabReceitaLocal') {
      name = 'Local';
    } else if (tab === 'subTabReceitaServico') {
      name = 'Servico';
    }
    const btn = document.getElementsByName(`imageInput-${name}`)[0];
    btn.click();
  }
  
  get disabledPlateActions() {
    if (document.getElementsByName('formUnidade').length > 0) {
      const unidade = Metadata.getInstance<Form>('formUnidade').value;
      if (unidade.UNIDADEFORM?.CDFILIAL) return false;
      return true;
    }
    return true;
  }
}
